@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : autogen-all-variants.sh
-# Copyright  : 2011-2023 by Peter Bieringer <pb (at) bieringer.de>
+# Copyright  : 2011-2025 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information: run autogen.sh with all supported variants
 #
@@ -14,27 +14,81 @@ status_file="autogen-all-variants.status"
 ## Generate configure variants
 autogen_variants() {
 	autogen_variants_list
-	autogen_variants_list | while IFS="#" read options list; do
-		echo "${options:+$options }--clang#$list"
-	done
 
-	autogen_variants_list | while IFS="#" read options list; do
-		echo "${options:+$options }--gcc-Os#$list"
+	autogen_variants_list | while IFS="#" read token options testlist; do
+		options_extra=""
+		if [[ $token =~ APACHE ]]; then
+			# https://github.com/pbiering/ipv6calc/issues/45
+			options_extra=" --disable-mod_ipv6calc"
+		fi
+		echo "$token#${options:+$options } --clang$options_extra#$testlist"
 	done
 
 	case "$OSTYPE" in
 	    freebsd*)
-		    # skip 32-bit builds on freebsd
-		    return
-		    ;;
+		# skip 32-bit builds on FreeBSD
+		return
+		;;
 	esac
 
-	# skip IP2Location and MaxMindDB based
-	autogen_variants_list | grep -Evw "(IP2LOCATION|GEOIP2|DBIP2)" | while IFS="#" read options list; do
-		echo "${options:+$options }--m32#$list"
+	if [ -e /etc/os-release ]; then
+		source /etc/os-release
+	fi
+
+	skip32=""
+	el=""
+	if [ -n "$VERSION_ID" ]; then
+		if [ -n "$ID_LIKE" ]; then
+			if [[ $ID_LIKE =~ (rhel|centos) ]]; then
+				el=1
+				if [ ${VERSION_ID/.*} -ge 9 ]; then
+					# skip 32-bit builds on Enterprise Linux 9+
+					skip32=1
+				fi
+			fi
+		fi
+		if [ -n "$ID" ]; then
+			if [[ $ID =~ (rhel|centos|almalinux) ]]; then
+				el=1
+				if [ ${VERSION_ID/.*} -ge 9 ]; then
+					# skip 32-bit builds on Enterprise Linux 9+
+					skip32=1
+				fi
+			fi
+		fi
+	fi
+
+	if [ "$skip32" = 1 ]; then
+		return
+	fi
+
+	# 32-bit builds
+	autogen_variants_list  | while IFS="#" read token options testlist; do
+		if [ "$el" = 1 ]; then
+			if [[ $token =~ IP2LOCATION ]]; then
+				# skip 32-bit builds on Enterprise Linux as IP2Location devel is not built for i686 on EPEL
+				continue
+			fi
+		fi
+
+		echo "$token#${options:+$options } --m32#$teslist"
 	done
-	autogen_variants_list | grep -Evw "(IP2LOCATION|GEOIP2|DBIP2)" | while IFS="#" read options list; do
-		echo "${options:+$options }--clang --m32#$list"
+
+	# 32-bit builds with clang
+	autogen_variants_list  | while IFS="#" read token options testlist; do
+		if [[ $token =~ APACHE ]]; then
+			# https://github.com/pbiering/ipv6calc/issues/45
+			options_extra=" --disable-mod_ipv6calc"
+		fi
+
+		if [ "$el" = 1 ]; then
+			if [[ $token =~ IP2LOCATION ]]; then
+				# skip 32-bit builds on Enterprise Linux as IP2Location devel is not built for i686 on EPEL
+				continue
+			fi
+		fi
+
+		echo "$token#${options:+$options } --clang --m32$options_extra#$testlist"
 	done
 }
 
@@ -42,19 +96,35 @@ autogen_variants_list() {
 	if ! $skip_main_test; then
 		cat <<END | grep -v ^#
 NONE#
+NONE#--external
 BUNDLED#--enable-bundled-md5 --enable-bundled-getopt
 OPENSSL#--enable-openssl-md5 --no-static-build
 OPENSSL#--enable-openssl-evp-md5
+LIBMD#--enable-libmd-md5 --no-static-build
 IP2LOCATION#-i
-IP2LOCATION#-i --ip2location-dyn
-GEOIP2 DBIP2#-m
-GEOIP2 DBIP2#-m --mmdb-dyn
+IP2LOCATION#-I
+GEOIP2 DBIP2 IP2LOCATION2#-m
+GEOIP2 DBIP2 IP2LOCATION2#-M
 GEOIP2#-m --disable-dbip2
 GEOIP2#-M --disable-dbip2
+GEOIP2#-m --disable-dbip2 --disable-ip2location2
+GEOIP2#-M --disable-dbip2 --disable-ip2location2
+GEOIP2#-m --disable-ip2location2
+GEOIP2#-M --disable-ip2location2
 DBIP2#-m --disable-geoip2
 DBIP2#-M --disable-geoip2
-IP2LOCATION GEOIP2 DBIP2#-a
-IP2LOCATION GEOIP2 DBIP2#-A
+DBIP2#-m --disable-geoip2 --disable-ip2location2
+DBIP2#-M --disable-geoip2 --disable-ip2location2
+DBIP2#-m --disable-ip2location2
+DBIP2#-M --disable-ip2location2
+IP2LOCATION2#-m --disable-dbip2
+IP2LOCATION2#-M --disable-dbip2
+IP2LOCATION2#-m --disable-dbip2 --disable-geoip2
+IP2LOCATION2#-M --disable-dbip2 --disable-geoip2
+IP2LOCATION2#-m --disable-geoip2
+IP2LOCATION2#-M --disable-geoip2
+APACHE IP2LOCATION GEOIP2 DBIP2 IP2LOCATION2#-a
+APACHE IP2LOCATION GEOIP2 DBIP2 IP2LOCATION2#-A
 NONE#--disable-db-ieee
 NONE#--disable-db-ipv4
 NONE#--disable-db-ipv6
@@ -102,6 +172,7 @@ $0
 	-i	run through internal defined IP2Location versions
 	-D	enable dynamic library loading in run through versions	
 	-M	skip main tests
+	-T	skip "make test"
 	-n	dry-run, show only what would be build
 	-c	cross version test
 	-b	batch test (do not stop on error)
@@ -117,10 +188,11 @@ force=false
 no_static_build=false
 rerun=false
 skip_main_test=false
+skip_make_test=false
 skip_shared=false
 ip2location_versions_test=false
 
-while getopts ":cbDNMirIfWn?h" opt; do
+while getopts ":cbDNMTirIfWn?h" opt; do
 	case $opt in
 	    'b')
 		batch=true
@@ -140,6 +212,9 @@ while getopts ":cbDNMirIfWn?h" opt; do
 	    'M')
 		skip_main_test=true
 		;;
+	    'T')
+		skip_make_test=true
+		;;
 	    'I')
 		skip_token="IP2LOCATION"
 		;;
@@ -268,17 +343,19 @@ for liboption in "normal" "shared"; do
 			fi
 		fi
 
-		if echo "$token" | grep -Ewq "$skip_token"; then
-			echo "NOTICE: skip variant because of token: $token"
-			if $dry_run; then
-				date "+%s:FINISHED:variants:$options:SKIPPED" >>$status_file
+		if [ -n "$skip_token" ]; then
+			if echo "$token" | grep -Ewq "$skip_token"; then
+				echo "NOTICE: skip variant because of token: $token"
+				if $dry_run; then
+					date "+%s:FINISHED:variants:$options:SKIPPED" >>$status_file
+				fi
+				continue
 			fi
-			continue
 		fi
 
 		options_test=""
 
-		if [ -n "$testlist" ]; then
+		if $skip_make_test; then
 			options_test="--no-test"
 		fi
 
