@@ -2,12 +2,12 @@
 #
 # Project    : ipv6calc/databases/cc-assignment
 # File       : check-run-create.sh
-# Version    : $Id: 20a824e62817236ced91deca0d9995dba316b0e0 $
-# Copyright  : 2013-2013 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: e4f0d4ac6fa7889feefaab56fea850ed36f07f11 $
+# Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
 
 #set -x
 
-flag_update=0
+flag_update=false
 file_header="dbasn_assignment.h"
 
 if [ -f $file_header ]; then
@@ -20,13 +20,13 @@ if [ -f $file_header ]; then
 	echo "Found newer than $file_header file: ARIN=$ARIN APNIC=$APNIC RIPENCC=$RIPENCC LACNIC=$LACNIC AFRINIC=$AFRINIC"
 
 	if [ $ARIN -gt 0 -o $APNIC -gt 0 -o $RIPENCC -gt 0 -o $LACNIC -gt 0 -o $AFRINIC -gt 0 ]; then
-		flag_update=1
+		flag_update=true
 	fi
 else
-	flag_update=1
+	flag_update=true
 fi
 
-if [ $flag_update -eq 1 ]; then
+if $flag_update; then
 	./create-asn-registry-list.pl
 else
 	echo " Nothing to do!"
