@@ -1,8 +1,8 @@
  /*
  * Project       : ipv6calc
  * File          : dbasn_assignment.h
- * Version       : $Id: 3ca2000bc3f2d97c4656d1fad55725e370927898 $
- * Generated     : Thu Jun  8 18:30:30 2023
+ * Version       : $Id: 17ce140d3b0e374e236139f0dcff08550df38c7a $
+ * Generated     : Mon Jun 16 06:13:29 2025
  * Data copyright: IANA
  *
  * Information:
@@ -11,7 +11,7 @@
 
 #include "libipv6calc.h"
 
-/*@unused@*/ static const char* dbasn_registry_status __attribute__ ((__unused__)) = "IANA/20230510";
+/*@unused@*/ static const char* dbasn_registry_status __attribute__ ((__unused__)) = "IANA/20250117";
 
 static const s_asn_assignment dbasn_assignment[] = {
 	{          1,       1876, REGISTRY_ARIN       },
@@ -120,6 +120,8 @@ static const s_asn_assignment dbasn_assignment[] = {
 	{     150842,     151865, REGISTRY_APNIC      },
 	{     151866,     152889, REGISTRY_APNIC      },
 	{     152890,     153913, REGISTRY_APNIC      },
+	{     153914,     154937, REGISTRY_APNIC      },
+	{     154938,     155961, REGISTRY_APNIC      },
 	{     196608,     197631, REGISTRY_RIPENCC    },
 	{     197632,     198655, REGISTRY_RIPENCC    },
 	{     198656,     199679, REGISTRY_RIPENCC    },
@@ -137,6 +139,9 @@ static const s_asn_assignment dbasn_assignment[] = {
 	{     210332,     211355, REGISTRY_RIPENCC    },
 	{     211356,     212379, REGISTRY_RIPENCC    },
 	{     212380,     213403, REGISTRY_RIPENCC    },
+	{     213404,     214427, REGISTRY_RIPENCC    },
+	{     214428,     215451, REGISTRY_RIPENCC    },
+	{     215452,     216475, REGISTRY_RIPENCC    },
 	{     262144,     263167, REGISTRY_LACNIC     },
 	{     263168,     263679, REGISTRY_LACNIC     },
 	{     263680,     264604, REGISTRY_LACNIC     },
@@ -149,6 +154,7 @@ static const s_asn_assignment dbasn_assignment[] = {
 	{     270749,     271772, REGISTRY_LACNIC     },
 	{     271773,     272796, REGISTRY_LACNIC     },
 	{     272797,     273820, REGISTRY_LACNIC     },
+	{     273821,     274844, REGISTRY_LACNIC     },
 	{     327680,     328703, REGISTRY_AFRINIC    },
 	{     328704,     329727, REGISTRY_AFRINIC    },
 	{     393216,     394239, REGISTRY_ARIN       },
@@ -159,6 +165,7 @@ static const s_asn_assignment dbasn_assignment[] = {
 	{     398237,     399260, REGISTRY_ARIN       },
 	{     399261,     400284, REGISTRY_ARIN       },
 	{     400285,     401308, REGISTRY_ARIN       },
+	{     401309,     402332, REGISTRY_ARIN       },
 
 };
 
