@@ -2,12 +2,12 @@
 #
 # Project    : ipv6calc/databases/cc-assignment
 # File       : check-run-create.sh
-# Version    : $Id: 1003fad4ed2e996a10e95ed917a3821e82648c65 $
-# Copyright  : 2013-2013 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 554de5c647e95658571d7db3026a8ee10c2eff84 $
+# Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
 
 #set -x
 
-flag_update=0
+flag_update=false
 file_header="db_cc_reg_assignment.h"
 
 if [ -f $file_header ]; then
@@ -20,13 +20,13 @@ if [ -f $file_header ]; then
 	echo "Found newer than $file_header file: ARIN=$ARIN APNIC=$APNIC RIPENCC=$RIPENCC LACNIC=$LACNIC AFRINIC=$AFRINIC"
 
 	if [ $ARIN -gt 0 -o $APNIC -gt 0 -o $RIPENCC -gt 0 -o $LACNIC -gt 0 -o $AFRINIC -gt 0 ]; then
-		flag_update=1
+		flag_update=true
 	fi
 else
-	flag_update=1
+	flag_update=true
 fi
 
-if [ $flag_update -eq 1 ]; then
+if $flag_update; then
 	./create-cc-to-registry-list.pl
 else
 	echo " Nothing to do!"
