@@ -1,15 +1,15 @@
  /*
  * Project       : ipv6calc
  * File          : db_cc_reg_assignment.h
- * Version       : $Id: ddf5ff9cb83d18d7f345991badd3c6cc8ccce974 $
- * Generated     : Tue Jan 25 22:06:14 2022
+ * Version       : $Id: 85c263b17c8f9a842afa0a85e2ef7d93420a10ee $
+ * Generated     : Mon Jun 16 06:13:30 2025
  * Data copyright: RIPE NCC, APNIC, ARIN, LACNIC, AFRINIC
  *
  * Information:
  *  Additional header file for databases/lib/libipv6calc_db_wrapper_BuiltIn.c
  */
 
-static const char *db_cc_registry_status = "AFRINIC/20220124 APNIC/20220125 ARIN/20220125 LACNIC/20220121 RIPENCC/20220124";
+static const char *db_cc_registry_status = "AFRINIC/20250615 APNIC/20250615 ARIN/20250615 LACNIC/20250611 RIPENCC/20250615";
 
 static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "", REGISTRY_ARIN     },
@@ -149,7 +149,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "ME", REGISTRY_RIPENCC  },
 	{ "MF", REGISTRY_ARIN     },
 	{ "MG", REGISTRY_AFRINIC  },
-	{ "MH", REGISTRY_APNIC    },
+	{ "MH", REGISTRY_RIPENCC  },
 	{ "MK", REGISTRY_RIPENCC  },
 	{ "ML", REGISTRY_AFRINIC  },
 	{ "MM", REGISTRY_APNIC    },
@@ -222,7 +222,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "TG", REGISTRY_AFRINIC  },
 	{ "TH", REGISTRY_APNIC    },
 	{ "TJ", REGISTRY_RIPENCC  },
-	{ "TK", REGISTRY_APNIC    },
+	{ "TK", REGISTRY_RIPENCC  },
 	{ "TL", REGISTRY_APNIC    },
 	{ "TM", REGISTRY_RIPENCC  },
 	{ "TN", REGISTRY_AFRINIC  },
@@ -247,7 +247,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "WF", REGISTRY_APNIC    },
 	{ "WS", REGISTRY_APNIC    },
 	{ "YE", REGISTRY_RIPENCC  },
-	{ "YT", REGISTRY_RIPENCC  },
+	{ "YT", REGISTRY_AFRINIC  },
 	{ "ZA", REGISTRY_AFRINIC  },
 	{ "ZM", REGISTRY_AFRINIC  },
 	{ "ZW", REGISTRY_AFRINIC  },
@@ -708,7 +708,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  451  JH
 	{ REGISTRY_APNIC    }, //  452  KH
 	{ REGISTRY_UNKNOWN  }, //  453  LH
-	{ REGISTRY_APNIC    }, //  454  MH
+	{ REGISTRY_RIPENCC  }, //  454  MH
 	{ REGISTRY_UNKNOWN  }, //  455  NH
 	{ REGISTRY_UNKNOWN  }, //  456  OH
 	{ REGISTRY_APNIC    }, //  457  PH
@@ -793,7 +793,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  536  QK
 	{ REGISTRY_UNKNOWN  }, //  537  RK
 	{ REGISTRY_RIPENCC  }, //  538  SK
-	{ REGISTRY_APNIC    }, //  539  TK
+	{ REGISTRY_RIPENCC  }, //  539  TK
 	{ REGISTRY_UNKNOWN  }, //  540  UK
 	{ REGISTRY_UNKNOWN  }, //  541  VK
 	{ REGISTRY_UNKNOWN  }, //  542  WK
@@ -1032,7 +1032,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  775  VT
 	{ REGISTRY_UNKNOWN  }, //  776  WT
 	{ REGISTRY_UNKNOWN  }, //  777  XT
-	{ REGISTRY_RIPENCC  }, //  778  YT
+	{ REGISTRY_AFRINIC  }, //  778  YT
 	{ REGISTRY_UNKNOWN  }, //  779  ZT
 	{ REGISTRY_APNIC    }, //  780  AU
 	{ REGISTRY_UNKNOWN  }, //  781  BU
