@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper.h
- * Version    : $Id: 0dbed86cf1d322d0611f438a5505609cefb19624 $
- * Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2013-2025 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper.c
@@ -97,6 +96,7 @@ extern uint32_t wrapper_features_by_source_implemented[];
 #define IPV6CALC_DB_IP_TO_REGION		(IPV6CALC_DB_IPV4_TO_REGION    | IPV6CALC_DB_IPV6_TO_REGION   )
 #define IPV6CALC_DB_IP_TO_GEONAMEID		(IPV6CALC_DB_IPV4_TO_GEONAMEID | IPV6CALC_DB_IPV6_TO_GEONAMEID)
 
+//                                              0xXXUBBBBB 20 bit are blocked by above
 // define database specific generic features
 #define IPV6CALC_DB_GEOIP_IPV4			0x01000000
 #define IPV6CALC_DB_GEOIP_IPV6			0x02000000
@@ -112,14 +112,18 @@ extern uint32_t wrapper_features_by_source_implemented[];
 #define IPV6CALC_DB_EXTERNAL_IPV4		0x40000000
 #define IPV6CALC_DB_EXTERNAL_IPV6		0x80000000
 
+#define IPV6CALC_DB_IP2LOCATION2_IPV4		0x00400000
+#define IPV6CALC_DB_IP2LOCATION2_IPV6		0x00800000
 
 static const s_formatoption ipv6calc_db_features[] = {
-	{ IPV6CALC_DB_GEOIP_IPV4	, "GeoIP"		, "GeoIPv4 database"},
-	{ IPV6CALC_DB_GEOIP_IPV6	, "GeoIPv6"		, "GeoIPv6 database"},
-	{ IPV6CALC_DB_IP2LOCATION_IPV4	, "IP2Location"		, "IP2Location IPv4 database"},
-	{ IPV6CALC_DB_IP2LOCATION_IPV6	, "IP2Location6"	, "IP2Location IPv6 database"},
-	{ IPV6CALC_DB_DBIP_IPV4		, "DBIPv4"		, "db-ip.com IPv4 database"},
-	{ IPV6CALC_DB_DBIP_IPV6		, "DBIPv6"		, "db-ip.com IPv6 database"},
+	{ IPV6CALC_DB_GEOIP_IPV4	, "GeoIP"		, "GeoIP(MMDB) IPv4 database"},
+	{ IPV6CALC_DB_GEOIP_IPV6	, "GeoIPv6"		, "GeoIP(MMDB) IPv6 database"},
+	{ IPV6CALC_DB_IP2LOCATION_IPV4	, "IP2Location"		, "IP2Location(BIN) IPv4 database"},
+	{ IPV6CALC_DB_IP2LOCATION_IPV6	, "IP2Location6"	, "IP2Location(BIN) IPv6 database"},
+	{ IPV6CALC_DB_IP2LOCATION2_IPV4	, "IP2Location2"	, "IP2Location(MMDB) IPv4 database"},
+	{ IPV6CALC_DB_IP2LOCATION2_IPV6	, "IP2Location2v6"	, "IP2Location(MMDB) IPv6 database"},
+	{ IPV6CALC_DB_DBIP_IPV4		, "DBIPv4"		, "db-ip.com(MMDB) IPv4 database"},
+	{ IPV6CALC_DB_DBIP_IPV6		, "DBIPv6"		, "db-ip.com(MMDB) IPv6 database"},
 	{ IPV6CALC_DB_AS_TO_REGISTRY	, "DB_AS_REG"		, "AS-Number to Registry database"},
 	{ IPV6CALC_DB_IPV4_TO_REGISTRY	, "DB_IPV4_REG"		, "IPv4 to Registry database"},
 	{ IPV6CALC_DB_IPV6_TO_REGISTRY	, "DB_IPV6_REG"		, "IPv6 to Registry database"},
@@ -150,13 +154,12 @@ static const s_formatoption ipv6calc_db_features[] = {
 
 #define IPV6CALC_DB_SOURCE_GEOIP2		1
 #define IPV6CALC_DB_SOURCE_IP2LOCATION		2
-#define IPV6CALC_DB_SOURCE_DBIP2		3
-#define IPV6CALC_DB_SOURCE_GEOIP		4
-#define IPV6CALC_DB_SOURCE_DBIP			5
-#define IPV6CALC_DB_SOURCE_EXTERNAL		6
-#define IPV6CALC_DB_SOURCE_BUILTIN		7
+#define IPV6CALC_DB_SOURCE_IP2LOCATION2		3
+#define IPV6CALC_DB_SOURCE_DBIP2		4
+#define IPV6CALC_DB_SOURCE_EXTERNAL		5
+#define IPV6CALC_DB_SOURCE_BUILTIN		6
 
-#define IPV6CALC_DB_SOURCE_MAX			7
+#define IPV6CALC_DB_SOURCE_MAX			6
 
 #define IPV6CALC_DB_PRIO_MAX			IPV6CALC_DB_SOURCE_MAX
 
@@ -167,13 +170,12 @@ typedef struct {
 } s_data_sources;
 
 static const s_data_sources data_sources[] = {
-	{ IPV6CALC_DB_SOURCE_GEOIP	, "GeoIP"      , "GeoIP"       },
-	{ IPV6CALC_DB_SOURCE_GEOIP2	, "GeoIP(MaxMindDB)"    , "GeoIP2"      },
-	{ IPV6CALC_DB_SOURCE_IP2LOCATION, "IP2Location", "IP2Location" },
-	{ IPV6CALC_DB_SOURCE_DBIP	, "db-ip.com"  , "DBIP"        },
-	{ IPV6CALC_DB_SOURCE_DBIP2	, "db-ip.com(MaxMindDB)", "DBIP2"       },
-	{ IPV6CALC_DB_SOURCE_EXTERNAL	, "External"   , "External"    },
+	{ IPV6CALC_DB_SOURCE_GEOIP2	, "GeoIP(MMDB)"    , "GeoIP2"      },
+	{ IPV6CALC_DB_SOURCE_IP2LOCATION, "IP2Location(BIN)", "IP2Location" },
+	{ IPV6CALC_DB_SOURCE_DBIP2	, "db-ip.com(MMDB)", "DBIP2"       },
+	{ IPV6CALC_DB_SOURCE_EXTERNAL	, "External(BDB)"   , "External"    },
 	{ IPV6CALC_DB_SOURCE_BUILTIN	, "BuiltIn"    , "BuiltIn"     },
+	{ IPV6CALC_DB_SOURCE_IP2LOCATION2, "IP2Location(MMDB)", "IP2Location2" },
 };
 
 // database names and descriptions
@@ -290,7 +292,28 @@ static const s_data_sources geonameid_types[] = {
 #define IPV6CALC_DL_STATUS_UNKNOWN	0
 #define IPV6CALC_DL_STATUS_ERROR	-1
 
-// db-info macro
+
+// db_info
+#define UNPACK_YM(dbym) ((dbym > 0) ? (((dbym % 12) + 1) + ((dbym / 12)) * 100) : 0)
+
+typedef struct {
+	unsigned int num;
+	int dbtype;
+	int dbym;
+} s_libipv6calc_db_wrapper_db_info;
+
+
+typedef struct {
+	s_libipv6calc_db_wrapper_db_info	country4;
+	s_libipv6calc_db_wrapper_db_info	country6;
+	s_libipv6calc_db_wrapper_db_info	city4;
+	s_libipv6calc_db_wrapper_db_info	city6;
+	s_libipv6calc_db_wrapper_db_info	asn4;
+	s_libipv6calc_db_wrapper_db_info	asn6;
+	s_libipv6calc_db_wrapper_db_info	geonameid4;
+	s_libipv6calc_db_wrapper_db_info	geonameid6;
+} s_libipv6calc_db_wrapper_db_info_all;
+
 #define IPV6CALC_DB_FEATURE_INFO(prefix, data_source) \
         fprintf(stderr, "%s%s: features available/implemented: 0x%08x/0x%08x", \
 		prefix, \
@@ -379,6 +402,7 @@ extern void libipv6calc_db_wrapper_features(char *string, const size_t size);
 extern void libipv6calc_db_wrapper_capabilities(char *string, const size_t size);
 extern void libipv6calc_db_wrapper_features_help(void);
 extern void libipv6calc_db_wrapper_print_db_info(const int level_verbose, const char *prefix_string);
+extern void libipv6calc_db_wrapper_print_db_info_line(const int level_verbose, const char *prefix_string, const char *db_string, const char *db_info_string, const int db_length, const s_libipv6calc_db_wrapper_db_info_all db_info_all, const int suppress);
 extern void libipv6calc_db_wrapper_print_features_verbose(const int level_verbose);
 extern int  libipv6calc_db_wrapper_has_features(uint32_t features);
 extern int  libipv6calc_db_wrapper_options(const int opt, const char *optarg, const struct option longopts[]);
@@ -393,8 +417,8 @@ extern int         libipv6calc_db_wrapper_country_code_by_cc_index(char *string,
 extern uint16_t    libipv6calc_db_wrapper_cc_index_by_country_code(const char *cc_text);
 extern uint16_t    libipv6calc_db_wrapper_cc_index_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
 
-// Autonomous System Text/Number
-extern uint32_t    libipv6calc_db_wrapper_as_num32_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
+// Autonomous System Number/Text
+extern uint32_t    libipv6calc_db_wrapper_as_num32_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr, char *as_orgname, const size_t as_orgname_length);
 
 extern uint32_t    libipv6calc_db_wrapper_as_num32_comp17(const uint32_t as_num32);
 extern uint32_t    libipv6calc_db_wrapper_as_num32_decomp17(const uint32_t as_num32_comp17);
@@ -442,6 +466,8 @@ extern int libipv6calc_db_wrapper_bdb_fetch_row(
 #endif // HAVE_BERKELEY_DB_SUPPORT
 
 // generic DB lookup
+extern int (*get_array_row)(const int i, const uint32_t *value_first_00_31, const uint32_t *value_first_32_63, const uint32_t *value_last_00_31, const uint32_t *value_last_32_63);
+
 extern long int libipv6calc_db_wrapper_get_entry_generic(
 	void 		*db_ptr,		// pointer to database in case of IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_BDB, otherwise NULL
 	const uint8_t	data_ptr_type,		// type of data_ptr
@@ -453,7 +479,7 @@ extern long int libipv6calc_db_wrapper_get_entry_generic(
 	const uint32_t	lookup_key_00_31,	// lookup key MSB
 	const uint32_t	lookup_key_32_63,	// lookup key LSB
 	void            *data_ptr,		// pointer to DB data in case of IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_BDB, otherwise NULL
-	int  (*get_array_row)()			// function to get array row
+	int  (*get_array_row)(const uint32_t row, uint32_t *key_first_00_31_ptr, uint32_t *key_first_32_63_ptr, uint32_t *key_last_00_31_ptr, uint32_t *key_last_32_63_ptr)			// function to get array row
 	);
 
 /* filter powered by database */
