@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_DBIP2.h
- * Version    : $Id: 1dc2fd06ea40b694490889eb9062073f9bb18d22 $
- * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2019-2025 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper_DBIP2.c
@@ -18,19 +17,16 @@
 // database types
 #define DBIP2_DB_COUNTRY_LITE				1
 #define DBIP2_DB_CITY_LITE				2
-#define DBIP2_DB_COUNTRY				3	// commercial
-#define DBIP2_DB_LOCATION				4	// commercial
-#define DBIP2_DB_ISP					5	// commercial
-#define DBIP2_DB_LOCATION_ISP				6	// commercial
+#define DBIP2_DB_ASN_LITE				3
+#define DBIP2_DB_COUNTRY				4	// commercial
+#define DBIP2_DB_LOCATION				5	// commercial
+#define DBIP2_DB_ISP					6	// commercial
+#define DBIP2_DB_LOCATION_ISP				7	// commercial
 #define DBIP2_DB_MAX					DBIP2_DB_LOCATION_ISP
 
-#define IPV6CALC_DB_DBIP2_INTERNAL_FREE		0x00000001
+#define IPV6CALC_DB_DBIP2_INTERNAL_LITE		0x00000001
 #define IPV6CALC_DB_DBIP2_INTERNAL_COMM		0x00000002
 
-
-// features
-extern uint32_t wrapper_features_DBIP2;
-
 #endif
 
 
@@ -47,7 +43,7 @@ extern int         libipv6calc_db_wrapper_DBIP2_has_features(const uint32_t feat
 #include "libipv6calc_db_wrapper_MMDB.h"
 
 extern int         libipv6calc_db_wrapper_DBIP2_wrapper_country_code_by_addr(const ipv6calc_ipaddr *ipaddrp, char *country, const size_t country_len);
-extern uint32_t    libipv6calc_db_wrapper_DBIP2_wrapper_asn_by_addr(const ipv6calc_ipaddr *ipaddrp);
+extern uint32_t    libipv6calc_db_wrapper_DBIP2_wrapper_asn_by_addr(const ipv6calc_ipaddr *ipaddrp, char *as_orgname, const size_t as_orgname_length);
 extern uint32_t    libipv6calc_db_wrapper_DBIP2_wrapper_GeonameID_by_addr(const ipv6calc_ipaddr *ipaddrp, int *source_ptr);
 extern int         libipv6calc_db_wrapper_DBIP2_all_by_addr(const ipv6calc_ipaddr *ipaddrp, libipv6calc_db_wrapper_geolocation_record *recordp);
 
