@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : showinfo.c
- * Version    : $Id: 83584c41857d2b55f6e77d788980ed5f6004d835 $
- * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2001-2025 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Function to show information about a given IPv6 address
@@ -28,10 +27,9 @@
 
 #include "../databases/lib/libipv6calc_db_wrapper.h"
 #include "../databases/lib/libipv6calc_db_wrapper_MMDB.h"
-#include "../databases/lib/libipv6calc_db_wrapper_GeoIP.h"
 #include "../databases/lib/libipv6calc_db_wrapper_GeoIP2.h"
 #include "../databases/lib/libipv6calc_db_wrapper_IP2Location.h"
-#include "../databases/lib/libipv6calc_db_wrapper_DBIP.h"
+#include "../databases/lib/libipv6calc_db_wrapper_IP2Location2.h"
 #include "../databases/lib/libipv6calc_db_wrapper_DBIP2.h"
 #include "../databases/lib/libipv6calc_db_wrapper_External.h"
 #include "../databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
@@ -48,7 +46,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, "\nAvailable tokens for machine-readable output (printed in one line):\n");
 	fprintf(stderr, " IPV6_TYPE=...                 : type of IPv6 address (commata separated)\n");
 	fprintf(stderr, " ");
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
+	for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++ ) {
 		fprintf(stderr, " %s", ipv6calc_ipv6addrtypestrings[i].token);
 	};
 	fprintf(stderr, "\n");
@@ -57,6 +55,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IPV6_REGISTRY=...             : registry token of given IPv6 address\n");
 	fprintf(stderr, " IPV6_PREFIXLENGTH=ddd         : given prefix length\n");
 	fprintf(stderr, " IPV6_AS_NUM=...               : AS number of (anonymized) IPv6 address\n");
+	fprintf(stderr, " IPV6_AS_ORGNAME=...           : AS organisation name of (anonymized) IPv6 address\n");
 	fprintf(stderr, " IPV6_AS_SOURCE=...            : Source of AS number of IPv6 address\n");
 	fprintf(stderr, " IPV6_GEONAME_ID=...           : GeonameID of (anonymized) IPv6 address\n");
 	fprintf(stderr, " IPV6_GEONAME_ID_SOURCE=...    : Source of GeonameID number of IPv6 address\n");
@@ -65,7 +64,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IPV6_COUNTRYCODE_SOURCE=...   : Source of Country Code of IPv6 address\n");
 	fprintf(stderr, " IPV4_TYPE=...                 : type of IPv4 address (commata separated)\n");
 	fprintf(stderr, " ");
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
+	for (i = 0; i < ipv6calc_ipv4addrtypestrings_entries; i++ ) {
 		fprintf(stderr, " %s", ipv6calc_ipv4addrtypestrings[i].token);
 	};
 	fprintf(stderr, "\n");
@@ -74,6 +73,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IPV4_REGISTRY=...             : registry token of native IPv4 address\n");
 	fprintf(stderr, " IPV4_PREFIXLENGTH=ddd         : given prefix length of native IPv4 address\n");
 	fprintf(stderr, " IPV4_AS_NUM=...               : AS number of (anonymized) IPv4 address\n");
+	fprintf(stderr, " IPV4_AS_ORGNAME=...           : AS organisation name of (anonymized) IPv4 address\n");
 	fprintf(stderr, " IPV4_AS_SOURCE=...            : Source of AS number of (anonymized) IPv4 address\n");
 	fprintf(stderr, " IPV4_COUNTRYCODE=...          : Country Code of (anonymized) IPv4 address\n");
 	fprintf(stderr, " IPV4_COUNTRYCODE_SOURCE=...   : Source of Country Code of (anonymized) IPv4 address\n");
@@ -95,8 +95,8 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " TEREDO_PORT_CLIENT=...        : port of Teredo client (NAT outside)\n");
 	fprintf(stderr, " AS_NUM=...                    : Autonomous System Number\n");
 	fprintf(stderr, " AS_NUM_REGISTRY=...           : Registry of AS number\n");
-#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP || defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP || defined DBIP2
-	fprintf(stderr, "Prefix: IP2LOCATION, GEOIP, GEOIP2, DBIP, DBIP2\n");
+#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP2 || defined DBIP2
+	fprintf(stderr, "Prefix: IP2LOCATION, GEOIP2, DBIP2\n");
 	fprintf(stderr, " (output can vary depending on database provider and type Free/Commercial)\n");
 	fprintf(stderr, " <prefix>_CONTINENT_SHORT=...  : Continent Code of IP address\n");
 	fprintf(stderr, " <prefix>_CONTINENT_LONG=...   : Continent Name of IP address\n");
@@ -114,7 +114,7 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " <prefix>_GEONAME_ID_DISTRICT= : GeoName ID of District of IP address\n");
 	fprintf(stderr, " <prefix>_AREACODE=...         : Area code of IP address\n");
 	fprintf(stderr, " <prefix>_DMACODE=...          : DMA/Metro code of IP address\n");
-	fprintf(stderr, " <prefix>_IDDCODE=...          : Internation Direct Dialing of IP address\n");
+	fprintf(stderr, " <prefix>_IDDCODE=...          : International Direct Dialing of IP address\n");
 	fprintf(stderr, " <prefix>_LATITUDE=...         : Latitude of IP address\n");
 	fprintf(stderr, " <prefix>_LONGITUDE=...        : Longitude of IP address\n");
 	fprintf(stderr, " <prefix>_RADIUS=...           : Radius around Latitude/Longitude of IP address\n");
@@ -154,8 +154,9 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, "          --mrqva (always) --mrqvn (never)\n");
 	fprintf(stderr, "       specific token can be selected using --mrst <TOKEN>\n");
 	fprintf(stderr, "         even in case of no/empty output: --mrstpa <TOKEN>\n");
+	fprintf(stderr, "         value of a specific token can be displayed using --mrtvo <TOKEN>\n");
+	fprintf(stderr, "         wildcard '.' is supported in select token\n");
 	fprintf(stderr, "       matching tokens can be selected using --mrmt <TOKEN>\n");
-	fprintf(stderr, "       value of a specific token can be displayed using --mrtvo <TOKEN>\n");
 };
 
 /*
@@ -163,10 +164,24 @@ void showinfo_availabletypes(void) {
  */
 static void printout(const char *token, const char *value, const uint32_t formatoptions) {
 	int quote = 0;
+	unsigned int i;
+
+	DEBUGPRINT_WA(DEBUG_showinfo, "called with token='%s' value='%s'", token, value);
 
 	if (formatoptions & FORMATOPTION_mr_select_token) {
-		// skip not matching token (equal)
-		if (strcmp(showinfo_machine_readable_filter, token) != 0) return;
+		if (strchr(showinfo_machine_readable_filter, '.')) {
+			// wildcard found, execute sophisticated check
+			if (strlen(showinfo_machine_readable_filter) != strlen(token)) return; // length not matching
+			for (i = 0; i < strlen(token); i++) {
+				if (showinfo_machine_readable_filter[i] == '.') {
+					continue; // skip
+				};
+				if (showinfo_machine_readable_filter[i] != token[i]) return; // not matching
+			};
+		} else {
+			// skip not matching token
+			if (strcmp(showinfo_machine_readable_filter, token) != 0) return;
+		};
 
 		showinfo_machine_readable_filter_used = 1;
 	};
@@ -213,13 +228,27 @@ static void printout(const char *token, const char *value, const uint32_t format
 
 static void printout2(const char *token, const char *additional, const char *value, const uint32_t formatoptions) {
 	int quote = 0;
+	unsigned int i;
+
+	DEBUGPRINT_WA(DEBUG_showinfo, "called with token='%s' additional='%s' value='%s'", token, additional, value);
 
 	if (formatoptions & FORMATOPTION_mr_select_token) {
 		// skip in case additional is not empty
 		if ((additional != NULL) && (strlen(additional) > 0)) return;
 
-		// skip not matching token
-		if (strcmp(showinfo_machine_readable_filter, token) != 0) return;
+		if (strchr(showinfo_machine_readable_filter, '.')) {
+			// wildcard found, execute sophisticated check
+			if (strlen(showinfo_machine_readable_filter) != strlen(token)) return; // length not matching
+			for (i = 0; i < strlen(token); i++) {
+				if (showinfo_machine_readable_filter[i] == '.') {
+					continue; // skip
+				};
+				if (showinfo_machine_readable_filter[i] != token[i]) return; // not matching
+			};
+		} else {
+			// skip not matching token
+			if (strcmp(showinfo_machine_readable_filter, token) != 0) return;
+		};
 
 		showinfo_machine_readable_filter_used = 1;
 	};
@@ -269,14 +298,14 @@ static void printout2(const char *token, const char *additional, const char *val
 };
 
 static void printfooter(const uint32_t formatoptions) {
-	char tempstring[NI_MAXHOST] = "";
-	char tempstring2[NI_MAXHOST] = "";
+	char tempstring[IPV6CALC_STRING_MAX] = "";
+	char tempstring2[IPV6CALC_STRING_MAX] = "";
 
 	if ((formatoptions & FORMATOPTION_mr_select_token_pa) && (showinfo_machine_readable_filter_used == 0)) {
 		printout(showinfo_machine_readable_filter, "", formatoptions);
 	};
 
-#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP || defined SUPPORT_DBIP || defined SUPPORT_EXTERNAL || defined SUPPORT_BUILTIN || defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP2 || defined SUPPORT_GEOIP2
+#if defined SUPPORT_IP2LOCATION || defined SUPPORT_EXTERNAL || defined SUPPORT_BUILTIN || defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP2 || SUPPORT_IP2LOCATION2
 	char *string;
 #endif
 
@@ -286,18 +315,18 @@ static void printfooter(const uint32_t formatoptions) {
 		if ( (formatoptions & FORMATOPTION_machinereadable) != 0 ) {
 			printout("IP2LOCATION_DATABASE_INFO", string, formatoptions);
 		} else {
-			fprintf(stdout, "IP2Location database: %s\n", string);
+			fprintf(stdout, "IP2Location(BIN) database: %s\n", string);
 		};
 	};
 #endif
 
-#ifdef SUPPORT_GEOIP
-	string = libipv6calc_db_wrapper_GeoIP_wrapper_db_info_used();
+#ifdef SUPPORT_IP2LOCATION2
+	string = libipv6calc_db_wrapper_IP2Location2_wrapper_db_info_used();
 	if ((string != NULL) && (strlen(string) > 0)) {
 		if ( (formatoptions & FORMATOPTION_machinereadable) != 0 ) {
-			printout("GEOIP_DATABASE_INFO", string, formatoptions);
+			printout("IP2LOCATION2_DATABASE_INFO", string, formatoptions);
 		} else {
-			fprintf(stdout, "GeoIP database: %s\n", string);
+			fprintf(stdout, "IP2Location(MMDB) database: %s\n", string);
 		};
 	};
 #endif
@@ -308,18 +337,7 @@ static void printfooter(const uint32_t formatoptions) {
 		if ( (formatoptions & FORMATOPTION_machinereadable) != 0 ) {
 			printout("GEOIP2_DATABASE_INFO", string, formatoptions);
 		} else {
-			fprintf(stdout, "GeoIP database:(MaxMindDB) %s\n", string);
-		};
-	};
-#endif
-
-#ifdef SUPPORT_DBIP
-	string = libipv6calc_db_wrapper_DBIP_wrapper_db_info_used();
-	if ((string != NULL) && (strlen(string) > 0)) {
-		if ( (formatoptions & FORMATOPTION_machinereadable) != 0 ) {
-			printout("DBIP_DATABASE_INFO", string, formatoptions);
-		} else {
-			fprintf(stdout, "DB-IP.com database: %s\n", string);
+			fprintf(stdout, "GeoIP(MMDB) database: %s\n", string);
 		};
 	};
 #endif
@@ -330,7 +348,7 @@ static void printfooter(const uint32_t formatoptions) {
 		if ( (formatoptions & FORMATOPTION_machinereadable) != 0 ) {
 			printout("DBIP2_DATABASE_INFO", string, formatoptions);
 		} else {
-			fprintf(stdout, "DB-IP.com (MaxMindDB) database: %s\n", string);
+			fprintf(stdout, "DB-IP.com(MMDB) database: %s\n", string);
 		};
 	};
 #endif
@@ -341,7 +359,7 @@ static void printfooter(const uint32_t formatoptions) {
 		if ( (formatoptions & FORMATOPTION_machinereadable) != 0 ) {
 			printout("EXTERNAL_DATABASE_INFO", string, formatoptions);
 		} else {
-			fprintf(stdout, "External database: %s\n", string);
+			fprintf(stdout, "External(MMDB) database: %s\n", string);
 		};
 	};
 #endif
@@ -374,23 +392,23 @@ static void printfooter(const uint32_t formatoptions) {
 		libipv6calc_db_wrapper_features(tempstring, sizeof(tempstring));
 
 		if (feature_zeroize == 1) {
-			snprintf(tempstring2, sizeof(tempstring2), "%s%sANON_ZEROISE", tempstring, strlen(tempstring) > 0 ? " " : "");
-			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+			STRCAT(tempstring, strlen(tempstring) > 0 ? " " : "");
+			STRCAT(tempstring, "ANON_ZEROISE");
 		};
 
 		if (feature_anon == 1) {
-			snprintf(tempstring2, sizeof(tempstring2), "%s%sANON_ANONYMIZE", tempstring, strlen(tempstring) > 0 ? " " : "");
-			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+			STRCAT(tempstring, strlen(tempstring) > 0 ? " " : "");
+			STRCAT(tempstring, "ANON_ANONYMIZE");
 		};
 
 		if (feature_kp == 1) {
-			snprintf(tempstring2, sizeof(tempstring2), "%s%sANON_KEEP-TYPE-ASN-CC", tempstring, strlen(tempstring) > 0 ? " " : "");
-			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+			STRCAT(tempstring, strlen(tempstring) > 0 ? " " : "");
+			STRCAT(tempstring, "ANON_KEEP-TYPE-ASN-CC");
 		};
 
 		if (feature_kg == 1) {
-			snprintf(tempstring2, sizeof(tempstring2), "%s%sANON_KEEP-TYPE-GEONAMEID", tempstring, strlen(tempstring) > 0 ? " " : "");
-			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+			STRCAT(tempstring, strlen(tempstring) > 0 ? " " : "");
+			STRCAT(tempstring, "ANON_KEEP-TYPE-GEONAMEID");
 		};
 
 		printout("IPV6CALC_FEATURES", tempstring, formatoptions | FORMATOPTION_mr_quote_default);
@@ -405,10 +423,10 @@ static void printfooter(const uint32_t formatoptions) {
 };
 
 
-#if defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP2 || defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP || defined SUPPORT_DBIP
+#if defined SUPPORT_GEOIP2 || SUPPORT_DBIP2 || SUPPORT_IP2LOCATION || SUPPORT_IP2LOCATION2
 // with prefix
 static void printout3(const char *token, const char *additional, const char *value, const uint32_t formatoptions, const char *prefix) {
-	char tokencomplete[NI_MAXHOST] = "";
+	char tokencomplete[IPV6CALC_STRING_MAX] = "";
 	snprintf(tokencomplete, sizeof(tokencomplete), "%s_%s", prefix, token);
 	printout2(tokencomplete, additional, value, formatoptions);
 };
@@ -447,7 +465,7 @@ static void print_geolocation(libipv6calc_db_wrapper_geolocation_record *record,
 	};
 
 
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable);
 
 	PRINT_RECORD_STRING(record->continent_code      , "CONTINENT_SHORT"     , "Continent Code")
@@ -502,7 +520,7 @@ static void print_ip2location(const ipv6calc_ipaddr *ipaddrp, const uint32_t for
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
 	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_IP2LOCATION] == 0) {
-		DEBUGPRINT_NA(DEBUG_showinfo, "IP2Location support not active");
+		DEBUGPRINT_NA(DEBUG_showinfo, "IP2Location(BIN) support not active");
 		return;
 	};
 
@@ -510,29 +528,29 @@ static void print_ip2location(const ipv6calc_ipaddr *ipaddrp, const uint32_t for
 	ret = libipv6calc_db_wrapper_IP2Location_all_by_addr(ipaddrp, &record);
 
 	if (ret == 0) {
-		print_geolocation(&record, formatoptions, additionalstring, "IP2LOCATION", "IP2Location");
+		print_geolocation(&record, formatoptions, additionalstring, "IP2LOCATION", "IP2Location(BIN)");
 	};
 };
 #endif
 
-#ifdef SUPPORT_GEOIP
-/* print GeoIP (legacy) information */
-static void print_geoip(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatoptions, const char *additionalstring) {
+#ifdef SUPPORT_IP2LOCATION2
+/* print IP2Location2 information */
+static void print_ip2location2(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatoptions, const char *additionalstring) {
+	libipv6calc_db_wrapper_geolocation_record record;
+	int ret;
+
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
-	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP] == 0) {
-		DEBUGPRINT_NA(DEBUG_showinfo, "GeoIP (legacy) support not active");
+	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_IP2LOCATION2] == 0) {
+		DEBUGPRINT_NA(DEBUG_showinfo, "IP2Location(MMDB) support not active");
 		return;
 	};
 
-	int ret;
-	libipv6calc_db_wrapper_geolocation_record record;
-
 	/* get all information */
-	ret = libipv6calc_db_wrapper_GeoIP_all_by_addr(ipaddrp, &record);
+	ret = libipv6calc_db_wrapper_IP2Location2_all_by_addr(ipaddrp, &record);
 
 	if (ret == 0) {
-		print_geolocation(&record, formatoptions, additionalstring, "GEOIP", "GeoIP (legacy)");
+		print_geolocation(&record, formatoptions, additionalstring, "IP2LOCATION2", "IP2Location(MMDB)");
 	};
 };
 #endif
@@ -543,7 +561,7 @@ static void print_geoip2(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatop
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
 	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] == 0) {
-		DEBUGPRINT_NA(DEBUG_showinfo, "GeoIP (MaxMindDB) support not active");
+		DEBUGPRINT_NA(DEBUG_showinfo, "GeoIP(MMDB) support not active");
 		return;
 	};
 
@@ -555,30 +573,7 @@ static void print_geoip2(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatop
 	ret = libipv6calc_db_wrapper_GeoIP2_all_by_addr(ipaddrp, &record);
 
 	if (ret == 0) {
-		print_geolocation(&record, formatoptions, additionalstring, "GEOIP2", "GeoIP (MaxMindDB)");
-	};
-};
-#endif
-
-#ifdef SUPPORT_DBIP
-/* print DBIP information */
-static void print_dbip(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatoptions, const char *additionalstring) {
-	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
-
-	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_DBIP] == 0) {
-		DEBUGPRINT_NA(DEBUG_showinfo, "DBIP support not active");
-		return;
-	};
-
-	int ret;
-
-	libipv6calc_db_wrapper_geolocation_record record;
-
-	/* get all information */
-	ret = libipv6calc_db_wrapper_DBIP_all_by_addr(ipaddrp, &record);
-
-	if (ret == 0) {
-		print_geolocation(&record, formatoptions, additionalstring, "DBIP", "DBIP (legacy)");
+		print_geolocation(&record, formatoptions, additionalstring, "GEOIP2", "GeoIP(MMDB)");
 	};
 };
 #endif
@@ -589,7 +584,7 @@ static void print_dbip2(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatopt
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
 	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_DBIP2] == 0) {
-		DEBUGPRINT_NA(DEBUG_showinfo, "DBIP2 support not active");
+		DEBUGPRINT_NA(DEBUG_showinfo, "DBIP(MMDB) support not active");
 		return;
 	};
 
@@ -601,7 +596,7 @@ static void print_dbip2(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatopt
 	ret = libipv6calc_db_wrapper_DBIP2_all_by_addr(ipaddrp, &record);
 
 	if (ret == 0) {
-		print_geolocation(&record, formatoptions, additionalstring, "DBIP2", "DB-IP.com (MaxMindDB)");
+		print_geolocation(&record, formatoptions, additionalstring, "DBIP2", "DB-IP.com(MMDB)");
 	};
 };
 #endif
@@ -612,7 +607,7 @@ static void print_external(const ipv6calc_ipaddr *ipaddrp, const uint32_t format
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
 	if (wrapper_features_by_source[IPV6CALC_DB_SOURCE_EXTERNAL] == 0) {
-		DEBUGPRINT_NA(DEBUG_showinfo, "External DB support not active");
+		DEBUGPRINT_NA(DEBUG_showinfo, "External(BDB) support not active");
 		return;
 	};
 
@@ -630,9 +625,9 @@ static void print_external(const ipv6calc_ipaddr *ipaddrp, const uint32_t format
 			printout2("EXTERNAL_COUNTRY_SHORT", additionalstring, returnedCountry, formatoptions);
 		} else {
 			if (strlen(additionalstring) > 0) {
-				fprintf(stdout, "External DB country code for %s: %s\n", additionalstring, returnedCountry);
+				fprintf(stdout, "External(BDB) country code for %s: %s\n", additionalstring, returnedCountry);
 			} else {
-				fprintf(stdout, "External DB country code: %s\n", returnedCountry);
+				fprintf(stdout, "External(BDB) country code: %s\n", returnedCountry);
 			};
 		};
 	};
@@ -641,9 +636,10 @@ static void print_external(const ipv6calc_ipaddr *ipaddrp, const uint32_t format
 
 /* print IPv4 address */
 static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t formatoptions, const char *string) {
-	char tempstring[NI_MAXHOST] = "", tempstring2[NI_MAXHOST] = "", tempstring3[NI_MAXHOST] = "", helpstring[NI_MAXHOST] = "";
-	char tempipv4string[NI_MAXHOST] = "";
-	char embeddedipv4string[NI_MAXHOST] = "";
+	char tempstring[IPV6CALC_STRING_MAX] = "", tempstring2[IPV6CALC_STRING_MAX] = "", tempstring3[IPV6CALC_STRING_MAX] = "";
+	char tempipv4string[IPV6CALC_STRING_MAX] = "";
+	char embeddedipv4string[IPV6CALC_STRING_MAX] = "";
+	char as_orgname[IPV6CALC_DB_SIZE_ORG_NAME] = "";
 	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable), as_num32 = ASNUM_AS_UNKNOWN;
 	int retval, i, j, retval_anon = 1, r;
 	ipv6calc_ipv4addr ipv4addr_anon, *ipv4addr_anon_ptr;
@@ -669,7 +665,10 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 	CONVERT_IPV4ADDRP_IPADDR(ipv4addrp, ipaddr);
 
 	if ((formatoptions & FORMATOPTION_printembedded) != 0) {
-		snprintf(embeddedipv4string, sizeof(embeddedipv4string), "[%s]", tempipv4string);
+		STRCLR(embeddedipv4string);
+		STRCAT(embeddedipv4string, "[");
+		STRCAT(embeddedipv4string, tempipv4string);
+		STRCAT(embeddedipv4string, "]");
 	};
 
 	ipv4addr_copy(ipv4addr_anon_ptr, ipv4addrp); /* copy structure */
@@ -715,10 +714,10 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		j = 0;
 
 		snprintf(tempstring, sizeof(tempstring), "%s", "ipv4");
-		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
+		for (i = 0; i < ipv6calc_ipv4addrtypestrings_entries; i++ ) {
 			if ((ipv4addrp->typeinfo & ipv6calc_ipv4addrtypestrings[i].number) != 0) {
-				snprintf(helpstring, sizeof(helpstring), "%s,%s", tempstring, ipv6calc_ipv4addrtypestrings[i].token);
-				snprintf(tempstring, sizeof(tempstring), "%s", helpstring);
+				STRCAT(tempstring, ",");
+				STRCAT(tempstring, ipv6calc_ipv4addrtypestrings[i].token);
 			};
 		};
 		printout2("IPV4_TYPE", embeddedipv4string, tempstring, formatoptions);
@@ -732,7 +731,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 
 		fprintf(stdout, "IPv4 address type: ");
 		j = 0;
-		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
+		for (i = 0; i < ipv6calc_ipv4addrtypestrings_entries; i++ ) {
 			if ((ipv4addrp->typeinfo & ipv6calc_ipv4addrtypestrings[i].number) != 0) {
 				if ( j != 0 ) { fprintf(stdout, ", "); };
 				fprintf(stdout, "%s", ipv6calc_ipv4addrtypestrings[i].token);
@@ -748,7 +747,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		as_num32 = libipv4addr_as_num32_by_addr(ipv4addrp, &data_source);
 		if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
 			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
-				as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, &data_source);
+				as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, &data_source, as_orgname, sizeof(as_orgname));
 			};
 		};
 
@@ -756,6 +755,9 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 			if ( machinereadable != 0 ) {
 				snprintf(tempstring, sizeof(tempstring), "%u", as_num32);
 				printout2("IPV4_AS_NUM", embeddedipv4string, tempstring, formatoptions);
+				if (strlen(as_orgname) > 0) {
+					printout2("IPV4_AS_ORGNAME", embeddedipv4string, as_orgname, formatoptions);
+				};
 
 				if (data_source != IPV6CALC_DB_SOURCE_UNKNOWN) {
 					for (i = 0; i < MAXENTRIES_ARRAY(data_sources); i++ ) {
@@ -768,8 +770,14 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 			} else {
 				if (strlen(embeddedipv4string) > 0) {
 					fprintf(stdout, "Autonomous System Number (32-bit) for %s: %d\n", embeddedipv4string, as_num32);
+					if (strlen(as_orgname) > 0) {
+						fprintf(stdout, "Autonomous System Organisation Name for %s: %s\n", embeddedipv4string, as_orgname);
+					};
 				} else {
 					fprintf(stdout, "Autonomous System Number (32-bit): %d\n", as_num32);
+					if (strlen(as_orgname) > 0) {
+						fprintf(stdout, "Autonomous System Organisation Name: %s\n", as_orgname);
+					};
 				};
 			};
 		} else {
@@ -840,19 +848,21 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 
 	DEBUGPRINT_NA(DEBUG_showinfo, "get registry");
 
+	STRCLR(tempstring2);
 	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) != 0) {
 		registry = libipv4addr_registry_num_by_addr(ipv4addrp);
-		snprintf(tempstring2, sizeof(tempstring2), "%s", libipv6calc_registry_string_by_num(registry));
+		STRCAT(tempstring2, libipv6calc_registry_string_by_num(registry));
 	} else {
 		libipv6calc_db_wrapper_registry_string_by_ipv4addr(ipv4addrp, tempstring, sizeof(tempstring));
-		snprintf(tempstring2, sizeof(tempstring2), "%s", tempstring);
+		STRCAT(tempstring2, tempstring);
 
-		DEBUGPRINT_NA(DEBUG_showinfo, "try to get additional information");
+		DEBUGPRINT_NA(DEBUG_showinfo, "try to get additional information from databases");
 		r = libipv6calc_db_wrapper_info_by_ipv4addr(ipv4addrp, tempstring3, sizeof(tempstring3));
 		if (r == 0) {
 			// info found, append to registry
-			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
-			snprintf(tempstring2, sizeof(tempstring2), "%s(%s)", tempstring, tempstring3);
+			STRCAT(tempstring2, "(");
+			STRCAT(tempstring2, tempstring3);
+			STRCAT(tempstring2, ")");
 		};
 	};
 
@@ -875,9 +885,9 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		print_ip2location(&ipaddr, formatoptions, embeddedipv4string);
 #endif
 
-#ifdef SUPPORT_GEOIP
-		/* GeoIP information */
-		print_geoip(&ipaddr, formatoptions, embeddedipv4string);
+#ifdef SUPPORT_IP2LOCATION2
+		/* IP2Location information */
+		print_ip2location2(&ipaddr, formatoptions, embeddedipv4string);
 #endif
 
 #ifdef SUPPORT_GEOIP2
@@ -885,11 +895,6 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		print_geoip2(&ipaddr, formatoptions, embeddedipv4string);
 #endif
 
-#ifdef SUPPORT_DBIP
-		/* db-ip.com information */
-		print_dbip(&ipaddr, formatoptions, embeddedipv4string);
-#endif
-
 #ifdef SUPPORT_DBIP2
 		/* db-ip.com (MaxMindDB) information */
 		print_dbip2(&ipaddr, formatoptions, embeddedipv4string);
@@ -909,7 +914,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
  * print ASN information
  */
 static void print_asn(const uint32_t asn, const uint32_t formatoptions) {
-	char helpstring[NI_MAXHOST];
+	char helpstring[IPV6CALC_STRING_MAX];
 	uint32_t machinereadable = ( formatoptions & FORMATOPTION_machinereadable);
 	int registry;
 
@@ -936,7 +941,7 @@ static void print_asn(const uint32_t asn, const uint32_t formatoptions) {
  * print EUI-48/MAC information
  */
 static void print_eui48(const ipv6calc_macaddr *macaddrp, const uint32_t formatoptions) {
-	char helpstring[NI_MAXHOST];
+	char helpstring[IPV6CALC_STRING_MAX];
 	uint32_t machinereadable = ( formatoptions & FORMATOPTION_machinereadable);
 	int i, result;
 	ipv6calc_ipv4addr ipv4addr;
@@ -1024,7 +1029,7 @@ static void print_eui48(const ipv6calc_macaddr *macaddrp, const uint32_t formato
  * print EUI-64 information
  */
 static void print_eui64(const ipv6calc_eui64addr *eui64addrp, const uint32_t formatoptions) {
-	char tempstring[NI_MAXHOST], helpstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX], helpstring[IPV6CALC_STRING_MAX];
 	uint32_t machinereadable = ( formatoptions & FORMATOPTION_machinereadable);
 	int result, i;
 	ipv6calc_macaddr macaddr;
@@ -1078,8 +1083,9 @@ static void print_eui64(const ipv6calc_eui64addr *eui64addrp, const uint32_t for
  */
 int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t formatoptions) {
 	int retval = 1, i, j, flag_prefixuse, registry, r, retval_anon = 1;
-	char tempstring[NI_MAXHOST] = "", tempstring2[NI_MAXHOST] = "", tempstring3[NI_MAXHOST] = "", helpstring[NI_MAXHOST] = "";
-	char ipv6addrstring[NI_MAXHOST] = "";
+	char tempstring[IPV6CALC_STRING_MAX] = "", tempstring2[IPV6CALC_STRING_MAX] = "", tempstring3[IPV6CALC_STRING_MAX] = "", helpstring[IPV6CALC_STRING_MAX] = "";
+	char ipv6addrstring[IPV6CALC_STRING_MAX] = "";
+	char as_orgname[IPV6CALC_DB_SIZE_ORG_NAME] = "";
 	ipv6calc_ipv6addr ipv6addr, ipv6addr_anon, *ipv6addrp, *ipv6addr_anon_ptr;
 	ipv6calc_ipv4addr ipv4addr, ipv4addr2;
 	ipv6calc_macaddr macaddr;
@@ -1102,11 +1108,11 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 	DEBUGPRINT_WA(DEBUG_showinfo, "typeinfo 0x%08x-0x%08x (from given address)", (unsigned int) ipv6addrp->typeinfo, (unsigned int) ipv6addrp->typeinfo2);
 
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
+	for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++ ) {
 		DEBUGPRINT_WA(DEBUG_showinfo, "test1: %08x : %s", (unsigned int) ipv6calc_ipv6addrtypestrings[i].number, ipv6calc_ipv6addrtypestrings[i].token);
 	};	
 
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addr_type2_strings); i++ ) {
+	for (i = 0; i < ipv6calc_ipv6addr_type2_strings_entries; i++ ) {
 		DEBUGPRINT_WA(DEBUG_showinfo, "test2: %08x : %s", (unsigned int) ipv6calc_ipv6addr_type2_strings[i].number, ipv6calc_ipv6addr_type2_strings[i].token);
 	};
 
@@ -1159,30 +1165,30 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 		j = 0;
 		snprintf(tempstring, sizeof(tempstring), "%s", "ipv6");
-		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
+		for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++ ) {
 			if ((ipv6addrp->typeinfo & ipv6calc_ipv6addrtypestrings[i].number) != 0) {
-				snprintf(helpstring, sizeof(helpstring), "%s,%s", tempstring, ipv6calc_ipv6addrtypestrings[i].token);
-				snprintf(tempstring, sizeof(tempstring), "%s", helpstring);
+				STRCAT(tempstring, ",");
+				STRCAT(tempstring, ipv6calc_ipv6addrtypestrings[i].token);
 			};
 		};
-		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addr_type2_strings); i++ ) {
+		for (i = 0; i < ipv6calc_ipv6addr_type2_strings_entries; i++ ) {
 			if ((ipv6addrp->typeinfo2 & ipv6calc_ipv6addr_type2_strings[i].number) != 0) {
-				snprintf(helpstring, sizeof(helpstring), "%s,%s", tempstring, ipv6calc_ipv6addr_type2_strings[i].token);
-				snprintf(tempstring, sizeof(tempstring), "%s", helpstring);
+				STRCAT(tempstring, ",");
+				STRCAT(tempstring, ipv6calc_ipv6addr_type2_strings[i].token);
 			};
 		};
 		printout("IPV6_TYPE", tempstring, formatoptions);
 	} else {
 		fprintf(stdout, "Address type: ");
 		j = 0;
-		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
+		for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++ ) {
 			if ((ipv6addrp->typeinfo & ipv6calc_ipv6addrtypestrings[i].number) != 0) {
 				if ( j != 0 ) { fprintf(stdout, ", "); };
 				fprintf(stdout, "%s", ipv6calc_ipv6addrtypestrings[i].token);
 				j = 1;
 			};
 		};
-		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addr_type2_strings); i++ ) {
+		for (i = 0; i < ipv6calc_ipv6addr_type2_strings_entries; i++ ) {
 			if ((ipv6addrp->typeinfo2 & ipv6calc_ipv6addr_type2_strings[i].number) != 0) {
 				if ( j != 0 ) { fprintf(stdout, ", "); };
 				fprintf(stdout, "%s", ipv6calc_ipv6addr_type2_strings[i].token);
@@ -1226,13 +1232,13 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		};
 
 		/* AS */
-		DEBUGPRINT_NA(DEBUG_showinfo, "get AS number/text");
+		DEBUGPRINT_NA(DEBUG_showinfo, "get AS number");
 		data_source = IPV6CALC_DB_SOURCE_UNKNOWN;
 		as_num32 = libipv6addr_as_num32_by_addr(ipv6addrp, &data_source);
 
 		if ((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) == 0) {
 			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_AS) == 1) {
-				as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, &data_source);
+				as_num32 = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, &data_source, as_orgname, sizeof(as_orgname));
 			};
 		};
 
@@ -1246,7 +1252,10 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 					} else {
 						snprintf(tempstring, sizeof(tempstring), "%d", as_num32);
 					};
-					printout("IPV6_AS_NUM" ,tempstring, formatoptions);
+					printout("IPV6_AS_NUM", tempstring, formatoptions);
+					if (strlen(as_orgname) > 0) {
+						printout("IPV6_AS_ORGNAME", as_orgname, formatoptions);
+					};
 
 					if (data_source != IPV6CALC_DB_SOURCE_UNKNOWN) {
 						for (i = 0; i < MAXENTRIES_ARRAY(data_sources); i++ ) {
@@ -1257,7 +1266,10 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 						};
 					};
 				} else {
-					fprintf(stdout, "ASN for address: %d\n", as_num32);
+					fprintf(stdout, "Autonomous System Number (32-bit): %d\n", as_num32);
+					if (strlen(as_orgname) > 0) {
+						fprintf(stdout, "Autonomous System Organisation Name: %s\n", as_orgname);
+					};
 				};
 			} else {
 				DEBUGPRINT_NA(DEBUG_showinfo, "Skip AS print: as_num32=ASNUM_AS_UNKNOWN");
@@ -1301,20 +1313,22 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 	/* IPv6 Registry */
 	DEBUGPRINT_NA(DEBUG_showinfo, "get registry");
+	STRCLR(tempstring2);
 	if (((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) != 0) \
 		&& ((ipv6addrp->typeinfo & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX) == 0)) {
 		registry = libipv6addr_registry_num_by_addr(ipv6addrp);
-		snprintf(tempstring2, sizeof(tempstring2), "%s", libipv6calc_registry_string_by_num(registry));
+		STRCAT(tempstring2, libipv6calc_registry_string_by_num(registry));
 	} else {
 		libipv6calc_db_wrapper_registry_string_by_ipv6addr(ipv6addrp, tempstring, sizeof(tempstring));
-		snprintf(tempstring2, sizeof(tempstring2), "%s", tempstring);
+		STRCAT(tempstring2, tempstring);
 
 		DEBUGPRINT_NA(DEBUG_showinfo, "try to get additional information");
 		r = libipv6calc_db_wrapper_info_by_ipv6addr(ipv6addrp, tempstring3, sizeof(tempstring3));
 		if (r == 0) {
 			// info found, append to registry
-			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
-			snprintf(tempstring2, sizeof(tempstring2), "%s(%s)", tempstring, tempstring3);
+			STRCAT(tempstring2, "(");
+			STRCAT(tempstring2, tempstring3);
+			STRCAT(tempstring2, ")");
 		};
 	};
 
@@ -1511,7 +1525,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 				if ((payload & 0x1000000) != 0) {
 					libieee_unmap_oui_macaddr(&macaddr, payload);
 				} else {
-					macaddr.addr[0] = ((payload >> 16) & 0xff) ^ 0x02;
+					macaddr.addr[0] = ((payload >> 16) & 0xff);
 					macaddr.addr[1] = (payload >> 8) & 0xff;
 					macaddr.addr[2] = (payload & 0xff);
 					macaddr.addr[3] = 0;
@@ -1536,7 +1550,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 					if ((payload & 0x1000000) != 0) {
 						libieee_unmap_oui_eui64addr(&eui64addr, payload);
 					} else  {
-						eui64addr.addr[0] = ((payload >> 16) & 0xff) ^ 0x02;
+						eui64addr.addr[0] = ((payload >> 16) & 0xff);
 						eui64addr.addr[1] = (payload >> 8) & 0xff;
 						eui64addr.addr[2] = (payload & 0xff);
 						eui64addr.addr[3] = 0;
@@ -1663,7 +1677,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 END:
 
 	i = libipv6calc_db_wrapper_registry_num_by_ipv6addr(ipv6addrp);
-	if ((i != IPV6_ADDR_REGISTRY_RESERVED) && (i != IPV6_ADDR_REGISTRY_6BONE)) {
+	if ((i != REGISTRY_RESERVED) && (i != REGISTRY_6BONE)) {
 		if (((ipv6addrp->typeinfo & IPV6_NEW_ADDR_AGU) != 0) && ((ipv6addrp->typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID | IPV6_ADDR_ANONYMIZED_PREFIX)) == 0)) {
 
 			if (((ipv6addrp->typeinfo2 & IPV6_ADDR_TYPE2_ANON_MASKED_PREFIX) != 0)\
@@ -1676,9 +1690,9 @@ END:
 			print_ip2location(&ipaddr, formatoptions, "");
 #endif
 
-#ifdef SUPPORT_GEOIP
-			/* GeoIP information */
-			print_geoip(&ipaddr, formatoptions, "");
+#ifdef SUPPORT_IP2LOCATION2
+			/* IP2Location information */
+			print_ip2location2(&ipaddr, formatoptions, "");
 #endif
 
 #ifdef SUPPORT_GEOIP2
@@ -1686,11 +1700,6 @@ END:
 			print_geoip2(&ipaddr, formatoptions, "");
 #endif
 
-#ifdef SUPPORT_DBIP
-			/* db-ip.com information */
-			print_dbip(&ipaddr, formatoptions, "");
-#endif
-
 #ifdef SUPPORT_DBIP2
 			/* db-ip.com (MaxMindDB) information */
 			print_dbip2(&ipaddr, formatoptions, "");
