@@ -2,8 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_showinfo.sh
-# Version    : $Id: 1c4ff4305253b5b90f098215cd455a47f5d429e6 $
-# Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
+# Copyright  : 2002-2025 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc showinfo
 
@@ -34,8 +33,8 @@ ff02::1:ff00:1234			# Solicited node link-local multicast address
 ff01::1:ff00:1234			# Solicited node link-local multicast address
 3ffe::1:ff00:1234			# Solicited node 6bone multicast address
 ::1					# localhost
-::2.2.3.4				# compat IPv4
-::ffff:2.2.3.4				# mapped IPv4
+::8.8.8.8				# compat IPv4
+::ffff:8.8.8.8				# mapped IPv4
 2002:0102:0204::1			# 6to4
 fe80::210:a4ff:fe01:2345		# link-local autoconfig EUI-48
 fe80::210:a489:ab01:2345		# link-local autoconfig EUI-64
@@ -124,7 +123,7 @@ testscenarios_ipv4_reserved | while read address rfc rest; do
 			$verbose || echo
 			echo "ERROR: unexpected result for $address (should: $rfc)"
 			./ipv6calc -q -i -m $address | grep ^IPV4_REGISTRY
-			exit 1	
+			exit 1
 		fi
 		;;
 	    noRFC)
@@ -132,7 +131,7 @@ testscenarios_ipv4_reserved | while read address rfc rest; do
 			$verbose || echo
 			echo "ERROR: unexpected result for $address (should not contain RFC token)"
 			./ipv6calc -q -i -m $address | grep ^IPV4_REGISTRY
-			exit 1	
+			exit 1
 		fi
 		;;
 	esac
@@ -153,7 +152,7 @@ testscenarios_ipv6_reserved | while read address rfc rest; do
 			$verbose || echo
 			echo "ERROR: unexpected result (should: $rfc)"
 			./ipv6calc -q -i -m $address | grep ^IPV6_REGISTRY
-			exit 1	
+			exit 1
 		fi
 		;;
 	    noRFC)
@@ -161,7 +160,7 @@ testscenarios_ipv6_reserved | while read address rfc rest; do
 			$verbose || echo
 			echo "ERROR: unexpected result (should not contain RFC token)"
 			./ipv6calc -q -i -m $address | grep ^IPV6_REGISTRY
-			exit 1	
+			exit 1
 		fi
 		;;
 	esac
@@ -227,7 +226,7 @@ testscenarios_showinfo | while read address output_options; do
 		$verbose || echo
 		echo "ERROR: unexpected result for $address ($output_escaped)"
 		./ipv6calc $options -q -i -m $address
-		exit 1	
+		exit 1
 	fi
 	$verbose && echo || true
 	$verbose || echo -n "."
@@ -241,7 +240,7 @@ if [ "$1" = "minimal" ]; then
 fi
 
 
-test="run GeoIP tests"
+test="run GeoIP(MMDB) tests"
 if ./ipv6calc -q -v 2>&1 | grep -qw GeoIP; then
 	echo "INFO  : $test"
 	getexamples_GeoIP | while read address; do
@@ -310,7 +309,7 @@ else
 fi
 
 
-test="run IP2Location tests"
+test="run IP2Location(BIN) tests"
 if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location; then
 	echo "INFO  : $test"
 	getexamples_IP2Location | while read address; do
@@ -329,7 +328,7 @@ if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location; then
 	$verbose || echo
 	echo "INFO  : $test successful"
 
-	test="run IP2Location showinfo tests"
+	test="run IP2Location(BIN) showinfo tests"
 	echo "INFO  : $test"
 	testscenarios_showinfo_ip2location | while read address output; do
 		if echo "$output" | grep -q "^OUI="; then
@@ -345,7 +344,7 @@ if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location; then
 		if ! ./ipv6calc -q -i -m $address | grep $grepopt "^$output_escaped$"; then
 			echo "ERROR: unexpected result for address $address ($output_escaped)"
 			./ipv6calc -q -i -m $address
-			exit 1	
+			exit 1
 		fi
 		$verbose && echo
 		$verbose || echo -n "."
@@ -354,7 +353,7 @@ if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location; then
 	echo "INFO  : $test successful"
 
 	if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location6; then
-		test="run IP2Location IPv6 tests"
+		test="run IP2Location(BIN) IPv6 tests"
 		echo "INFO  : $test"
 		getexamples_IP2Location6 | while read address; do
 			$verbose && echo "Run IP2Location IPv6 showinfo on: $address"
@@ -371,7 +370,7 @@ if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location; then
 		$verbose || echo
 		echo "INFO  : $test successful"
 
-		test="run IP2Location IPv6 showinfo tests"
+		test="run IP2Location(BIN) IPv6 showinfo tests"
 		echo "INFO  : $test"
 		testscenarios_showinfo_ip2location6 | while read address output; do
 			if echo "$output" | grep -q "^OUI="; then
@@ -388,7 +387,7 @@ if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location; then
 				$verbose || echo
 				echo "ERROR: unexpected result for $address ($output_escaped)"
 				./ipv6calc -q -i -m $address
-				exit 1	
+				exit 1
 			fi
 			$verbose && echo
 			$verbose || echo -n "."
@@ -400,6 +399,97 @@ else
 	echo "NOTICE: $test SKIPPED"
 fi
 
+test="run IP2Location(MMDB) tests"
+if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location2; then
+	echo "INFO  : $test"
+	getexamples_IP2Location | while read address; do
+		$verbose && echo "Run IP2Location(MMDB) IPv4 showinfo on: $address"
+		if ./ipv6calc -q -i -m $address | grep -Ev '=This (record|parameter) ' | grep $grepopt ^IP2LOCATION2_; then
+			true
+		else
+			$verbose || echo
+			echo "Unexpected result (missing IP2LOCATION2): ./ipv6calc -q -i -m $address"
+			./ipv6calc -q -i -m $address
+			exit 1
+		fi
+		$verbose && echo
+		$verbose || echo -n "."
+	done || exit 1
+	$verbose || echo
+	echo "INFO  : $test successful"
+
+	test="run IP2Location(MMDB) showinfo tests"
+	echo "INFO  : $test"
+	testscenarios_showinfo_ip2location | while read address output; do
+		output=${output/IP2LOCATION_/IP2LOCATION2_} # map expected result
+		if echo "$output" | grep -q "^OUI="; then
+			if ! $ipv6calc_has_db_ieee; then
+				$verbose && echo "Test: $address for $output SKIPPED (no DB_IEEE compiled in)"
+				continue
+			fi
+		fi
+		$verbose && echo "Test: $address for $output"
+		output_escaped="${output//./\\.}"
+		output_escaped="${output_escaped//[/\\[}"
+		output_escaped="${output_escaped//]/\\]}"
+		if ! ./ipv6calc -q -i -m $address | grep $grepopt "^$output_escaped$"; then
+			echo "ERROR: unexpected result for address $address ($output_escaped)"
+			./ipv6calc -q -i -m $address
+			exit 1
+		fi
+		$verbose && echo
+		$verbose || echo -n "."
+	done || exit 1
+	$verbose || echo
+	echo "INFO  : $test successful"
+
+	if ./ipv6calc -q -v 2>&1 | grep -qw IP2Location2v6; then
+		test="run IP2Location(MMDB) IPv6 tests"
+		echo "INFO  : $test"
+		getexamples_IP2Location6 | while read address; do
+			$verbose && echo "Run IP2Location(MMDB) IPv6 showinfo on: $address"
+			if ./ipv6calc -q -i -m $address | grep -Ev '=This (record|parameter) ' | grep $grepopt ^IP2LOCATION2_; then
+				true
+			else
+				echo "Unexpected result (missing IP2LOCATION2): ./ipv6calc -q -i -m $address"
+				./ipv6calc -q -i -m $address
+				exit 1
+			fi
+			$verbose && echo
+			$verbose || echo -n "."
+		done || exit 1
+		$verbose || echo
+		echo "INFO  : $test successful"
+
+		test="run IP2Location(MMDB) IPv6 showinfo tests"
+		echo "INFO  : $test"
+		testscenarios_showinfo_ip2location6 | while read address output; do
+			output=${output/IP2LOCATION_/IP2LOCATION2_} # map expected result
+			if echo "$output" | grep -q "^OUI="; then
+				if ! $ipv6calc_has_db_ieee; then
+					echo "Test: $address for $output SKIPPED (no DB_IEEE compiled in)"
+					continue
+				fi
+			fi
+			$verbose && echo "Test: $address for $output"
+			output_escaped="${output//./\\.}"
+			output_escaped="${output_escaped//[/\\[}"
+			output_escaped="${output_escaped//]/\\]}"
+			if ! ./ipv6calc -q -i -m $address | grep $grepopt "^$output_escaped$"; then
+				$verbose || echo
+				echo "ERROR: unexpected result for $address ($output_escaped)"
+				./ipv6calc -q -i -m $address
+				exit 1
+			fi
+			$verbose && echo
+			$verbose || echo -n "."
+		done || exit 1
+		$verbose || echo
+		echo "INFO  : $test successful"
+	fi
+else
+	echo "NOTICE: $test SKIPPED"
+fi
 
 test="run db-ip.com IPv4 tests"
 if ./ipv6calc -q -v 2>&1 | grep -qw DBIPv4; then
@@ -437,7 +527,7 @@ if ./ipv6calc -q -v 2>&1 | grep -qw DBIPv4; then
 		if ! ./ipv6calc -q -i -m $address | grep -E $grepopt "^$output_escaped$"; then
 			echo "ERROR: unexpected result ($output_escaped)"
 			./ipv6calc -q -i -m $address
-			exit 1	
+			exit 1
 		fi
 		$verbose && echo
 		$verbose || echo -n "."
@@ -486,7 +576,7 @@ if ./ipv6calc -q -v 2>&1 | grep -qw DBIPv6; then
 			$verbose || echo
 			echo "ERROR: unexpected result ($output_escaped)"
 			./ipv6calc -q -i -m $address
-			exit 1	
+			exit 1
 		fi
 		$verbose && echo
 		$verbose || echo -n "."
