@@ -1,9 +1,9 @@
-#!/bin/sh
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc/ipv6calcweb
 # File       : create_ipv6calcweb.sh
-# Version    : $Id: f28f2051a69a3e3cb5ca304d47567df89d9372e2 $
-# Copyright  : 2013-2013 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: f7bdd653f79d4ba635443d30bb3e946642f3689b $
+# Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information:
 #  create ipv6calcweb.cgi from ipv6calcweb.cgi.in
@@ -35,12 +35,19 @@ cp ipv6calcweb.cgi.in ipv6calcweb.cgi || exit 1
 perl -pi -e "s/\@PACKAGE_VERSION\@/$v/" ipv6calcweb.cgi || exit 1
 perl -pi -e "s/\@COPYRIGHT_YEAR\@/$c/" ipv6calcweb.cgi || exit 1
 
+case "$OSTYPE" in
+    freebsd*|openbsd*)
+	# *BSD has somehow issue with -T, so remove it
+	perl -pi -e "s/perl -w -T/perl -w/" ipv6calcweb.cgi || exit 1
+	;;
+esac
+
 if [ ! -x ipv6calcweb.cgi ]; then
 	chmod u+x ipv6calcweb.cgi
 fi
 
 if [ -f ipv6calcweb.cgi ]; then
-	touch ipv6calcweb.cgi -r ipv6calcweb.cgi.in
+	touch -r ipv6calcweb.cgi.in ipv6calcweb.cgi
 fi
 
 echo "INFO  : successfully created: ipv6calcweb.cgi"
