@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: e63ca446249fe7b23a02ed913d83c0ec41a042e2 $
- * Copyright  : 2007-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2007-2023 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile anonymization
@@ -568,7 +567,8 @@ static int anonymizetoken(char *resultstring, const size_t resultstring_length,
 
 		/* store key and value */
 		snprintf(cache_lru_key_token[cache_lru_last - 1], IPV6CALC_STRING_MAX, "%s", token);
-		snprintf(cache_lru_value[cache_lru_last - 1], IPV6CALC_STRING_MAX, "%s", resultstring);
+		STRCLR(cache_lru_value[cache_lru_last - 1]);
+		STRCAT(cache_lru_value[cache_lru_last - 1], resultstring);
 		DEBUGPRINT_WA(DEBUG_ipv6loganon_cache, "LRU cache: fill line=%d key_token=%s value=%s", cache_lru_last - 1, cache_lru_key_token[cache_lru_last - 1], cache_lru_value[cache_lru_last - 1]);
 	};
 
