@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.h
- * Version    : $Id: 946b042cdd3eeae2a64cef4ddc43a882f36ae76b $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 9699e2c949f5cf34c17fa0e8d414f087167781dd $
+ * Copyright  : 2002-2020 by Peter Bieringer <pb (at) bieringer.de>
  * License    : GNU GPL v2
  *
  * Information:
@@ -20,8 +20,7 @@
 #define DEBUG_ipv6logconv_general      0x00000001l
 #define DEBUG_ipv6logconv_processing   0x00000002l
 
-/* prototyping */
-int cache_lru_limit;
+extern int cache_lru_limit;
 
 extern int feature_reg;
 extern int feature_ieee;
