@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc/ipv6logstats
  * File       : ipv6logstats.c
- * Version    : $Id: 65e89a4b30f28413246245000c6d4a2a0dad97f8 $
- * Copyright  : 2003-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2003-2024 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile statistics
@@ -881,7 +880,7 @@ static void lineparser(void) {
 	if (opt_printdirection == 0) {
 		/* print used database only in row mode */
 
-#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP || defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP || defined SUPPORT_DBIP2 || defined SUPPORT_EXTERNAL || defined SUPPORT_BUILTIN
+#if defined SUPPORT_IP2LOCATION || defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP2 || defined SUPPORT_EXTERNAL || defined SUPPORT_BUILTIN
 		char *string;
 #endif
 
@@ -892,13 +891,6 @@ static void lineparser(void) {
 		};
 #endif
 
-#ifdef SUPPORT_GEOIP
-		string = libipv6calc_db_wrapper_GeoIP_wrapper_db_info_used();
-		if ((string != NULL) && (strlen(string) > 0)) {
-			printf("*3*DB-Used: %s\n", string);
-		};
-#endif
-
 #ifdef SUPPORT_GEOIP2
 		string = libipv6calc_db_wrapper_GeoIP2_wrapper_db_info_used();
 		if ((string != NULL) && (strlen(string) > 0)) {
@@ -906,13 +898,6 @@ static void lineparser(void) {
 		};
 #endif
 
-#ifdef SUPPORT_DBIP
-		string = libipv6calc_db_wrapper_DBIP_wrapper_db_info_used();
-		if ((string != NULL) && (strlen(string) > 0)) {
-			printf("*3*DB-Used: %s\n", string);
-		};
-#endif
-
 #ifdef SUPPORT_DBIP2
 		string = libipv6calc_db_wrapper_DBIP2_wrapper_db_info_used();
 		if ((string != NULL) && (strlen(string) > 0)) {
