@@ -2,8 +2,7 @@
 #
 # Project    : ipv6calc/logstats
 # File       : test_ipv6logstats.sh
-# Version    : $Id: bc2394cd3034c057c5c43423464e8e05eafa47df $
-# Copyright  : 2003-2021 by Peter Bieringer <pb (at) bieringer.de>
+# Copyright  : 2003-2025 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test program for "ipv6logstats"
 
@@ -63,19 +62,19 @@ END
 testscenarios_match() {
 	cat <<END | grep -v "^#"
 # Non-Anonymized IPv4
-2.2.3.4						AS-num-proto/3215/IPv4
-2.2.3.4						CC-proto-code/IPv4/FR
-::2.2.3.4					AS-num-proto/3215/IPv4
-::2.2.3.4					CC-proto-code/IPv4/FR
-::ffff:2.2.3.4					AS-num-proto/3215/IPv4
-::ffff:2.2.3.4					CC-proto-code/IPv4/FR
+8.8.8.8						AS-num-proto/15169/IPv4
+8.8.8.8						CC-proto-code/IPv4/US
+::8.8.8.8					AS-num-proto/15169/IPv4
+::8.8.8.8					CC-proto-code/IPv4/US
+::ffff:8.8.8.8					AS-num-proto/15169/IPv4
+::ffff:8.8.8.8					CC-proto-code/IPv4/US
 # Anonymized IPv4
-253.134.12.143					AS-num-proto/3215/IPv4
-253.134.12.143					CC-proto-code/IPv4/FR
-::253.134.12.143				AS-num-proto/3215/IPv4
-::253.134.12.143				CC-proto-code/IPv4/FR
-::ffff:253.134.12.143				AS-num-proto/3215/IPv4
-::ffff:253.134.12.143				CC-proto-code/IPv4/FR
+245.216.59.65					AS-num-proto/15169/IPv4
+245.216.59.65					CC-proto-code/IPv4/US
+::245.216.59.65					AS-num-proto/15169/IPv4
+::245.216.59.65					CC-proto-code/IPv4/US
+::ffff:245.216.59.65				AS-num-proto/15169/IPv4
+::ffff:245.216.59.65				CC-proto-code/IPv4/US
 # Teredo
 3ffe:831f:ce49:7601:8000:efff:af4a:86BF		CC-code-proto/IT/IPv4
 3ffe:831f:ce49:7601:8000:efff:af4a:86BF		AS-num-proto/3269/IPv4
@@ -87,15 +86,15 @@ testscenarios_match() {
 # 6to4
 2002:c0a8:f900:9:a929:4291:4021:132d		IPv6/6to4/RESERVED
 2002:c0a8:f900:9:a929:4291:4021:132d		CC-code-proto/unknown/IPv4
-2002:0202:0304:0:ed08:d22b:6c15:3401		CC-proto-code/IPv4/FR
-2002:0202:0304:0:ed08:d22b:6c15:3401		AS-num-proto/3215/IPv4
+2002:0808:0808:0:ed08:d22b:6c15:3401		CC-proto-code/IPv4/US
+2002:0808:0808:0:ed08:d22b:6c15:3401		AS-num-proto/15169/IPv4
 # 6to4 (anonymized)
 2002:f618:3b41:9:a929:4941::c			CC-proto-code/IPv4/AU
 2002:f618:3b41:9:a929:4941::c			AS-num-proto/15169/IPv4
 # NAT64
-64:ff9b::0202:0304				CC-proto-code/IPv4/FR
-64:ff9b::0202:0304				AS-num-proto/3215/IPv4
-64:ff9b::0202:0304				IPv6/NAT64/RIPE
+64:ff9b::0808:0808				CC-proto-code/IPv4/US
+64:ff9b::0808:0808				AS-num-proto/15169/IPv4
+64:ff9b::0808:0808				IPv6/NAT64/ARIN
 # NAT64 (anonmyized)
 64:ff9b::f618:3b41				CC-proto-code/IPv4/AU
 64:ff9b::f618:3b41				AS-num-proto/15169/IPv4
