@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.h
- * Version    : $Id: 147da5a50902b61a09f58504ba5347b94ae318af $
- * Copyright  : 2013-2020 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2013-2024 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file containing options
@@ -33,30 +32,16 @@ static struct option ipv6calc_longopts_common[] = {
 	{"db-ip2location-disable"      , 0, NULL, OPTION_NOOP },
 #endif
 
-	/* GeoIP(legacy) database options (EOS since 3.0.0, TODO remove 4.0.0) */
-	{"db-geoip"                    , 1, NULL, DB_EOS_geoip_ipv4         },
-	{"db-geoip-ipv4"               , 1, NULL, DB_EOS_geoip_ipv4         },
-	{"db-geoip-ipv6"               , 1, NULL, DB_EOS_geoip_ipv6         },
-	{"db-geoip-default"            , 0, NULL, (int) 'G'             },
-	{"db-geoip-ipv4-default"       , 0, NULL, DB_EOS_geoip_ipv4_default },
-	{"db-geoip-ipv6-default"       , 0, NULL, DB_EOS_geoip_ipv6_default },
-	{"disable-geoip"               , 0, NULL, DB_EOS_geoip_disable       },
-	{"db-geoip-disable"            , 0, NULL, DB_EOS_geoip_disable       },
-	{"db-geoip-dir"                , 1, NULL, DB_EOS_geoip_dir           },
-	{"db-geoip-lib"                , 1, NULL, DB_EOS_geoip_lib           },
+#ifndef SUPPORT_IP2LOCATION2
+	{"disable-ip2location2"         , 0, NULL, OPTION_NOOP },
+	{"db-ip2location2-disable"      , 0, NULL, OPTION_NOOP },
+#endif
 
 #ifndef SUPPORT_GEOIP2
 	{"disable-geoip2"              , 0, NULL, OPTION_NOOP },
 	{"db-geoip2-disable"           , 0, NULL, OPTION_NOOP },
 #endif
 
-	/* db-ip.com(BerkeleyDB) database options (EOS since 3.0.0, TODO remove 4.0.0) */
-	{"disable-dbip"                , 0, NULL, DB_EOS_dbip_disable       },
-	{"db-dbip-disable"             , 0, NULL, DB_EOS_dbip_disable       },
-	{"db-dbip-dir"                 , 1, NULL, DB_EOS_dbip_dir           },
-	{"db-dbip-comm-to-free-switch-min-delta-months", 1, NULL, DB_EOS_dbip_comm_to_free_switch_min_delta_months },
-	{"db-dbip-only-type", 1, NULL, DB_EOS_dbip_only_type },
-
 #ifndef SUPPORT_DBIP2
 	{"disable-dbip2"               , 0, NULL, OPTION_NOOP },
 	{"db-dbip2-disable"            , 0, NULL, OPTION_NOOP },
@@ -77,13 +62,6 @@ static struct option ipv6calc_longopts_common[] = {
 static char *ipv6calc_shortopts_ip2location = "L";
 
 static struct option ipv6calc_longopts_ip2location[] = {
-	/* database options (EOS since 3.0.0, TODO remove in 4.0.0) */
-	{"db-ip2location-ipv4"         , 1, NULL, DB_EOS_ip2location_ipv4   },
-	{"db-ip2location-ipv6"         , 1, NULL, DB_EOS_ip2location_ipv6   },
-	{"db-ip2location-default"      , 0, NULL, (int) 'L'             },
-	{"db-ip2location-ipv4-default" , 0, NULL, DB_EOS_geoip_ipv4_default },
-	{"db-ip2location-ipv6-default" , 0, NULL, DB_EOS_geoip_ipv6_default },
-
 	/* database options (new) */
 	{"disable-ip2location"         , 0, NULL, DB_ip2location_disable },
 	{"db-ip2location-disable"      , 0, NULL, DB_ip2location_disable },
@@ -101,6 +79,22 @@ static struct option ipv6calc_longopts_ip2location[] = {
 };
 #endif // SUPPORT_IP2LOCATION
 
+#ifdef SUPPORT_IP2LOCATION2
+static char *ipv6calc_shortopts_ip2location2 = "";
+
+static struct option ipv6calc_longopts_ip2location2[] = {
+	{"disable-ip2location2"         , 0, NULL, DB_ip2location2_disable },
+	{"db-ip2location2-disable"      , 0, NULL, DB_ip2location2_disable },
+	{"db-ip2location2-dir"          , 1, NULL, DB_ip2location2_dir     },
+
+	/* database selection control */
+	{"db-ip2location2-lite-to-sample-autoswitch-max-delta-months", 1, NULL, DB_ip2location2_lite_to_sample_autoswitch_max_delta_months },
+	{"db-ip2location2-comm-to-lite-switch-min-delta-months", 1, NULL, DB_ip2location2_comm_to_lite_switch_min_delta_months },
+	{"db-ip2location2-only-type", 1, NULL, DB_ip2location2_only_type },
+	{"db-ip2location2-allow-softlinks", 0, NULL, DB_ip2location2_allow_softlinks },
+};
+#endif // SUPPORT_IP2LOCATION2
+
 #ifdef SUPPORT_GEOIP2
 static char *ipv6calc_shortopts_geoip2 = "";
 
@@ -155,7 +149,7 @@ static struct option ipv6calc_longopts_builtin[] = {
 };
 #endif // SUPPORT_BUILTIN
 
-#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP || defined SUPPORT_GEOIP || SUPPORT_IP2LOCATION || defined SUPPORT_MMDB || defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP2
+#if defined SUPPORT_EXTERNAL || SUPPORT_IP2LOCATION || defined SUPPORT_MMDB || defined SUPPORT_GEOIP2 || defined SUPPORT_DBIP2 || SUPPORT_IP2LOCATION2
 static char *ipv6calc_shortopts_db_common = "";
 
 static struct option ipv6calc_longopts_db_common[] = {
