@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libieee.c
- * Version    : $Id: 0d1212734228f7aeb3dbc7b8e1d4f47215f0fb63 $
- * Copyright  : 2002-2022 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2002-2025 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library for IEEE information
@@ -379,6 +378,101 @@ static const s_ieee_mapping ieee_mapping[] = {
 	{ 0xD016F0,	IEEE_OUI28, 0x014b },
 	{ 0xD09395,	IEEE_OUI28, 0x014c },
 	{ 0xE03C1C,	IEEE_OUI28, 0x014d },
+
+	// OUI28 (2023-12-07)
+	{ 0x008DF4,	IEEE_OUI28, 0x014e },
+	{ 0x100648,	IEEE_OUI28, 0x014f },
+	{ 0x28F8C6,	IEEE_OUI28, 0x0150 },
+	{ 0x2CC44F,	IEEE_OUI28, 0x0151 },
+	{ 0x48DA35,	IEEE_OUI28, 0x0152 },
+	{ 0x4CEA41,	IEEE_OUI28, 0x0153 },
+	{ 0x5CF838,	IEEE_OUI28, 0x0154 },
+	{ 0x78392D,	IEEE_OUI28, 0x0155 },
+	{ 0x8C5570,	IEEE_OUI28, 0x0156 },
+	{ 0x8CA682,	IEEE_OUI28, 0x0157 },
+	{ 0x90A9F7,	IEEE_OUI28, 0x0158 },
+	{ 0xB84C87,	IEEE_OUI28, 0x0159 },
+	{ 0xC022F1,	IEEE_OUI28, 0x015a },
+	{ 0xC85CE2,	IEEE_OUI28, 0x015b },
+	{ 0xC898DB,	IEEE_OUI28, 0x015c },
+	{ 0xE8FF1E,	IEEE_OUI28, 0x015d },
+	{ 0xEC9A0C,	IEEE_OUI28, 0x015e },
+	{ 0xF41A79,	IEEE_OUI28, 0x015f },
+
+	// OUI28 (2023-12-18)
+	{ 0xD0A011,	IEEE_OUI28, 0x0160 },
+
+	// OUI28 (2024-01-20)
+	{ 0x34C8D6,	IEEE_OUI28, 0x0161 },
+	{ 0x78E996,	IEEE_OUI28, 0x0162 },
+	{ 0x80A579,	IEEE_OUI28, 0x0163 },
+
+	// OUI28 (2024-02-14)
+	{ 0x086332,	IEEE_OUI28, 0x0164 },
+	{ 0x901564,	IEEE_OUI28, 0x0165 },
+
+	// OUI28 (2024-06-05)
+	{ 0x08DA33,	IEEE_OUI28, 0x0166 },
+	{ 0x1063A3,	IEEE_OUI28, 0x0167 },
+	{ 0x344663,	IEEE_OUI28, 0x0168 },
+	{ 0x48E663,	IEEE_OUI28, 0x0169 },
+	{ 0x48E6C6,	IEEE_OUI28, 0x016a },
+	{ 0x5C5A4C,	IEEE_OUI28, 0x016b },
+	{ 0x5C87D8,	IEEE_OUI28, 0x016c },
+	{ 0x60A434,	IEEE_OUI28, 0x016d },
+	{ 0xC4CC37,	IEEE_OUI28, 0x016e },
+	{ 0xC8FFBF,	IEEE_OUI28, 0x016f },
+	{ 0xEC5BCD,	IEEE_OUI28, 0x0170 },
+	{ 0xF87A39,	IEEE_OUI28, 0x0171 },
+
+	// OUI28 (2024-08-18)
+	{ 0x248625,	IEEE_OUI28, 0x0172 },
+	{ 0x485E0E,	IEEE_OUI28, 0x0173 },
+	{ 0xAC86D1,	IEEE_OUI28, 0x0174 },
+	{ 0xC4FF84,	IEEE_OUI28, 0x0175 },
+	{ 0xECA7B1,	IEEE_OUI28, 0x0176 },
+	{ 0xF42055,	IEEE_OUI28, 0x0177 },
+	{ 0xF43AFA,	IEEE_OUI28, 0x0178 },
+
+	// OUI28 (2024-08-23)
+	{ 0xC0482F,	IEEE_OUI28, 0x0179 },
+
+	// OUI28 (2024-10-08)
+	{ 0x24A3F0,	IEEE_OUI28, 0x017a },
+	{ 0x3CDC03,	IEEE_OUI28, 0x017b },
+	{ 0x742584,	IEEE_OUI28, 0x017c },
+	{ 0xB0475E,	IEEE_OUI28, 0x017d },
+
+	// OUI28 (2025-01-06)
+	{ 0x0C47A9,	IEEE_OUI28, 0x017e },
+	{ 0x5823BC,	IEEE_OUI28, 0x017f },
+	{ 0x9088A9,	IEEE_OUI28, 0x0180 },
+	{ 0xA459D3,	IEEE_OUI28, 0x0181 },
+	{ 0xACEF92,	IEEE_OUI28, 0x0182 },
+	{ 0xBCDFE1,	IEEE_OUI28, 0x0183 },
+	{ 0xD0AA5F,	IEEE_OUI28, 0x0184 },
+	{ 0xEC74CD,	IEEE_OUI28, 0x0185 },
+
+	// OUI28 (2025-01-14)
+	{ 0x186696,	IEEE_OUI28, 0x0186 },
+
+	// OUI28 (2025-05-10)
+	{ 0x04A16F,	IEEE_OUI28, 0x0187 },
+	{ 0x04C98B,	IEEE_OUI28, 0x0188 },
+	{ 0x2C7AF4,	IEEE_OUI28, 0x0189 },
+	{ 0x380525,	IEEE_OUI28, 0x018a },
+	{ 0x6C27C8,	IEEE_OUI28, 0x018b },
+	{ 0x943EFD,	IEEE_OUI28, 0x018c },
+	{ 0x9CE549,	IEEE_OUI28, 0x018d },
+	{ 0xDC76C3,	IEEE_OUI28, 0x018e },
+	{ 0xF01204,	IEEE_OUI28, 0x018f },
+	{ 0xF82BE6,	IEEE_OUI28, 0x0190 },
+
+	// OUI28 (2025-06-16)
+	{ 0x04585D,	IEEE_OUI28, 0x0191 },
+	{ 0xB0CCCE,	IEEE_OUI28, 0x0192 },
+	{ 0xD4A0FB,	IEEE_OUI28, 0x0193 },
+	{ 0xFCA2DF,	IEEE_OUI28, 0x0194 },
 };
 
 
