@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6calc.c
- * Version    : $Id: 6356ab51637a313c5a616c76f1c334c5737f7716 $
- * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2001-2023 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library for some tools
@@ -18,11 +17,56 @@
 #include "ipv6calctypes.h"
 #include "libipv6calc.h"
 #include "libipv6calcdebug.h"
+#include "libipv6calc_filter.h"
 #include "librfc1924.h"
 #include "librfc2874.h"
 #include "librfc1886.h"
 
-#include "../databases/lib/libipv6calc_db_wrapper.h"
+#include "libipv6calc_db_wrapper.h"
+
+
+/* text representations */
+const s_ipv6calc_anon_set ipv6calc_anon_set_list[] = {
+	// name                   short  ip4 ip6 iid mac  keep-oui method
+	{ "anonymize-standard"  , "as"  , 24, 56, 40, 24, 1       , ANON_METHOD_ANONYMIZE     },
+	{ "anonymize-careful"   , "ac"  , 20, 48, 24, 24, 1       , ANON_METHOD_ANONYMIZE     },
+	{ "anonymize-paranoid"  , "ap"  , 16, 40,  0, 24, 0       , ANON_METHOD_ANONYMIZE     },
+	{ "zeroize-standard"    , "zs"  , 24, 56, 40, 24, 1       , ANON_METHOD_ZEROIZE       },
+	{ "zeroize-careful"     , "zc"  , 20, 48, 24, 24, 1       , ANON_METHOD_ZEROIZE       },
+	{ "zeroize-paranoid"    , "zp"  , 16, 40,  0, 24, 0       , ANON_METHOD_ZEROIZE       },
+	{ "keep-type-asn-cc"    , "kp"  , 24, 56, 40, 24, 1       , ANON_METHOD_KEEPTYPEASNCC },
+	{ "keep-type-geonameid" , "kg"  , 24, 56, 40, 24, 1       , ANON_METHOD_KEEPTYPEGEONAMEID }
+};
+
+const int ipv6calc_anon_set_list_entries = MAXENTRIES_ARRAY(ipv6calc_anon_set_list);
+
+
+const s_ipv6calc_anon_methods ipv6calc_anon_methods[] = {
+	{ "anonymize"        , 1, "reliable anonymization, keep as much type information as possible" },
+	{ "zeroize"          , 2, "simple zeroizing according to given masks, probably loose type information" },
+	{ "keep-type-asn-cc" , 3, "special reliable anonymization, keep type & Autonomous System Number and CountryCode" },
+	{ "keep-type-geonameid", 4, "special reliable anonymization, keep type & GeonameID" }
+};
+
+const int ipv6calc_anon_methods_entries = MAXENTRIES_ARRAY(ipv6calc_anon_methods);
+
+
+const s_type2 ipv6calc_registries[] = {
+        { REGISTRY_6BONE      , "6BONE"     , "REGISTRY_6BONE"   },
+        { REGISTRY_IANA       , "IANA"      , "REGISTRY_IANA"    },
+        { REGISTRY_APNIC      , "APNIC"     , "REGISTRY_APNIC"   },
+        { REGISTRY_ARIN       , "ARIN"      , "REGISTRY_ARIN"    },
+        { REGISTRY_RIPENCC    , "RIPENCC"   , "REGISTRY_RIPENCC" },
+        { REGISTRY_LACNIC     , "LACNIC"    , "REGISTRY_LACNIC"  },
+        { REGISTRY_AFRINIC    , "AFRINIC"   , "REGISTRY_AFRINIC" },
+        { REGISTRY_6TO4       , "6TO4"      , "REGISTRY_6TO4"    },
+        { REGISTRY_SRV6       , "SRV6"      , "REGISTRY_SRV6"    },
+        { REGISTRY_RESERVED   , "reserved"  , "REGISTRY_RESERVED"},
+        { REGISTRY_UNKNOWN    , "unknown"   , "REGISTRY_UNKNOWN" }
+};
+
+const int ipv6calc_registries_entries = MAXENTRIES_ARRAY(ipv6calc_registries);
+
 
 /*
  * function converts chars in a string to upcase
@@ -87,43 +131,61 @@ void string_to_reverse(char *string) {
 /*
  * dotted-reverse string
  * in : pointer to a string
+ * in : string length
  */
 void string_to_reverse_dotted(char *string, const size_t string_length) {
-	char resultstring[NI_MAXHOST], tempstring[NI_MAXHOST];
+	char resultstring[IPV6CALC_STRING_MAX] = "", tempstring[IPV6CALC_STRING_MAX] = "", splitstring[IPV6CALC_STRING_MAX];
 	char *token, *cptr, **ptrptr;
 	int flag_first = 1;
 	
 	ptrptr = &cptr;
 
+	DEBUGPRINT_NA(DEBUG_libipv6calc, "called");
+	if (strlen(string) < sizeof(splitstring)) {
+		snprintf(splitstring, sizeof(splitstring), "%s", string);
+	} else {
+		snprintf(string, string_length, "%s", "ERROR/INPUT-STRING-TOO-LONG/CANNOT-CREATE-REVERSE");
+		return;
+	};
+
 	/* clear result string */
-	snprintf(resultstring, sizeof(resultstring), "%s", "");
+	STRCLR(resultstring);
 
 	/* check for starting dot */
 	if ( string[0] == '.' ) {
-		snprintf(tempstring, sizeof(tempstring), "%s.", resultstring);
-		snprintf(resultstring, sizeof(resultstring), "%s", tempstring);
+		DEBUGPRINT_NA(DEBUG_libipv6calc, "1st char is dot");
+		STRCAT(resultstring, ".");
 	};
 
-	token = strtok_r(string, ".", ptrptr);
+	token = strtok_r(splitstring, ".", ptrptr);
 
 	while (token != NULL) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc, "split token: %s", token);
+		STRCLR(tempstring);
 		if (flag_first == 1) {
-			snprintf(tempstring, sizeof(tempstring), "%s%s", token, resultstring);
 			flag_first = 0;
+			STRCAT(tempstring, token);
 		} else {
-			snprintf(tempstring, sizeof(tempstring), "%s.%s", token, resultstring);
+			STRCAT(tempstring, token);
+			STRCAT(tempstring, ".");
+			STRCAT(tempstring, resultstring);
 		};
-		snprintf(resultstring, sizeof(resultstring), "%s", tempstring);
+		STRCLR(resultstring);
+		STRCAT(resultstring, tempstring);
 
 		token = strtok_r(NULL, ".", ptrptr);
 	};
 	
 	if ( string[strlen(string) - 1] == '.' ) {
-		snprintf(tempstring, sizeof(tempstring), ".%s", resultstring);
-		snprintf(resultstring, sizeof(resultstring), "%s", tempstring);
+		DEBUGPRINT_NA(DEBUG_libipv6calc, "last char is dot");
+		STRCLR(tempstring);
+		STRCAT(tempstring, ".");
+		STRCAT(tempstring, resultstring);
+		STRCLR(resultstring);
+		STRCAT(resultstring, tempstring);
 	};
 
-	snprintf(string, string_length, ".%s", resultstring);
+	snprintf(string, string_length, "%s", resultstring);
 	
 	return;
 };
@@ -138,8 +200,9 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 	uint32_t type = FORMAT_auto_noresult;
 	int i, j = 0, result;
 	unsigned int numdots = 0, numcolons = 0, numdigits = 0, numxdigits = 0, numdashes = 0, numspaces = 0, numslashes = 0, numalnums = 0, numchar_s = 0, numpercents = 0, numcolonsdouble = 0, xdigitlen_max = 0, xdigitlen_min = 0, xdl;
-	char resultstring[NI_MAXHOST];
+	char resultstring[IPV6CALC_STRING_MAX];
 	size_t length;
+	ipv6calc_ipv4addr ipv4addr;
 
 	length = strlen(string);
 
@@ -148,6 +211,12 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 		goto END_libipv6calc_autodetectinput;
 	};
 
+	ipv4addr_clearall(&ipv4addr);
+	if (addr_to_ipv4addrstruct(string, NULL, 0, &ipv4addr) == 0) {
+		type = FORMAT_ipv4addr;
+		goto END_libipv6calc_autodetectinput;
+	}
+
 	xdl = 0;
 	for (i = 0; i < (int) length; i++) {
 		if (string[i] == '.') { numdots++; };
@@ -214,14 +283,6 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 			goto END_libipv6calc_autodetectinput;
 		} else DEBUGPRINT_WA(DEBUG_libipv6calc, " check FORMAT_base85 not successful, result: %s", resultstring);
 	};
-	
-	if (((length >= 7 && length <= 15 && numdots == 3 && numcolons == 0 && numdigits == numxdigits && numdigits >= 4 && numdigits <= 12 && numslashes == 0 )
-	    || ((length >= 9 && length <= 18 && numdots == 3 && numcolons == 0 && numdigits == numxdigits && numdigits >= 5 && numdigits <= 14 && numslashes == 1)))
-	    && (numdots + numdigits + numslashes) == length) {
-		/* IPv4: d{1-3}.d{1-3}.d{1-3}.d{1-3} or d{1-3}.d{1-3}.d{1-3}.d{1-3}/d{1-2} */
-		type = FORMAT_ipv4addr;
-		goto END_libipv6calc_autodetectinput;
-	};
 
 	if ( strncmp(string, "\\[", 2) == 0 ) {
 		/* check for Bitstring label: \[x..../dd] */
@@ -374,13 +435,13 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 	
 	if (numcolons == 0 && numdots > 0 && numslashes == 0 && numspaces == 0 && (numalnums + numdots) == length) {
 		/* check for reverse nibble string */
-		DEBUGPRINT_NA(DEBUG_libipv6calc, " check FORMAT_revnibbels_int");
+		DEBUGPRINT_NA(DEBUG_libipv6calc, " check FORMAT_revnibbels_arpa");
 		result = librfc1886_formatcheck(string, resultstring, sizeof(resultstring));
 	        if ( result == 0 ) {
 			/* ok: reverse nibble string */
-			type = FORMAT_revnibbles_int;
+			type = FORMAT_revnibbles_arpa;
 			goto END_libipv6calc_autodetectinput;
-		} else DEBUGPRINT_WA(DEBUG_libipv6calc, " check FORMAT_revnibbels_int not successful, result: %s", resultstring);
+		} else DEBUGPRINT_WA(DEBUG_libipv6calc, " check FORMAT_revnibbels_arpa not successful, result: %s", resultstring);
 	};
 	
 	if ((numcolons == 3) && (numcolonsdouble == 0) && numdots == 0 && numslashes == 0 && numpercents == 0 && ((numcolons + numxdigits) == length)) {
@@ -497,7 +558,7 @@ void libipv6calc_filter_clear_db_registry(s_ipv6calc_filter_db_registry *filter_
  * ret: success
  */
 int libipv6calc_filter_parse(const char *expression, s_ipv6calc_filter_master *filter_master) {
-	char tempstring[NI_MAXHOST] = "";
+	char tempstring[IPV6CALC_STRING_MAX] = "";
 	char *charptr, *cptr, **ptrptr;
 	ptrptr = &cptr;
 	int r, token_used, result = 0;
@@ -728,6 +789,17 @@ int libipv6calc_bitcount_uint32_t(const uint32_t value) {
 	return(count);
 };
 
+
+/*
+ * cleanup
+ */
+void libipv6calc_cleanup() {
+	DEBUGPRINT_NA(DEBUG_libipv6calc, "called");
+	libipv4addr_cleanup();
+	libipv6calc_db_wrapper_cleanup();
+};
+
+
 /*
  * return library version numeric
  */
@@ -735,6 +807,8 @@ uint32_t libipv6calc_lib_version_numeric(void) {
 	return(IPV6CALC_PACKAGE_VERSION_NUMERIC);
 }; 
 
+
+
 /*
  * return library version as string
  */
@@ -743,6 +817,7 @@ const char *libipv6calc_lib_version_string(void) {
 
 };
 
+
 /*
  * return API version numeric
  */
@@ -750,6 +825,7 @@ uint32_t libipv6calc_api_version_numeric(void) {
 	return(IPV6CALC_API_VERSION_NUMERIC);
 };
 
+
 /*
  * return API version as string
  */
