@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6calc.h
- * Version    : $Id: 1b35045c66c8642bf8ba04c9c4b7477c1823260d $
- * Copyright  : 2001-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2001-2025 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc.c
@@ -25,6 +24,7 @@
 
 #define REGISTRY_6BONE        0x08
 #define REGISTRY_IANA         0x09
+#define REGISTRY_SRV6         0x0a
 #define REGISTRY_6TO4         0x0c
 #define REGISTRY_RESERVED     0x0e
 #define REGISTRY_UNKNOWN      0x0f
@@ -63,6 +63,55 @@
 		exit(1); \
 	};
 
+/* explicit exclude from "unused" warning */
+#define UNUSED(x) (void)(x)
+
+/* string functions */
+// STRCLR: clears a string
+#define STRCLR(dst) \
+	if (strlen(dst) > 0) { \
+		dst[0] = '\0'; \
+	};
+
+// STRCAT: concenate a string
+//  case 1: src can be added to dst completly
+//  case 2: src is too long to be added to dst, add only what is available but leave space for ...
+//  case 3: dst is already exhausted, override end with ...
+//  gcc 8.5 + 10.2 generates a false alarm because not proper analyzing the calculations
+#if __GNUC__ >= 8 && __GNUC__ <= 10
+
+#define STRCAT(dst, src) \
+	_Pragma("GCC diagnostic push") \
+	_Pragma("GCC diagnostic warning \"-Wstringop-overflow=0\"") \
+        if (sizeof(dst) > strlen(src) + strlen(dst)) { \
+                strncat(dst, src, ((sizeof(dst) - strlen(dst) - 1) > 0) ? (sizeof(dst) - strlen(dst) - 1) : 0); \
+        } else { \
+                if (sizeof(dst) > strlen(dst) + strlen("...")) { \
+                        strncat(dst, src, ((sizeof(dst) - strlen(dst) - strlen("...") - 1) > 0) ? (sizeof(dst) - strlen(dst) - strlen("...") - 1) : 0); \
+                        strcat(dst, "..."); \
+                } else if (strlen(dst) > strlen("...")) { \
+			dst[strlen(dst) - strlen("...")] = '\0'; \
+                        strcat(dst, "..."); \
+                }; \
+        }; \
+	_Pragma("GCC diagnostic pop")
+#else
+
+#define STRCAT(dst, src) \
+        if (sizeof(dst) > strlen(src) + strlen(dst)) { \
+                strncat(dst, src, ((sizeof(dst) - strlen(dst) - 1) > 0) ? (sizeof(dst) - strlen(dst) - 1) : 0); \
+        } else { \
+                if (sizeof(dst) > strlen(dst) + strlen("...")) { \
+                        strncat(dst, src, ((sizeof(dst) - strlen(dst) - strlen("...") - 1) > 0) ? (sizeof(dst) - strlen(dst) - strlen("...") - 1) : 0); \
+                        strcat(dst, "..."); \
+                } else if (strlen(dst) > strlen("...")) { \
+			dst[strlen(dst) - strlen("...")] = '\0'; \
+                        strcat(dst, "..."); \
+                }; \
+        };
+
+#endif
+
 #endif // _libipv6calc_h
 
 
