@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : librfc3041.c
- * Version    : $Id: 0315b321e4a91b7ddd3ab56652792a1d5b24fa31 $
- * Copyright  : 2001-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2001-2023 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library for host identifier privacy extension defined in RFC 3041 / RFC 4941
@@ -25,7 +24,13 @@
 #ifdef ENABLE_OPENSSL_EVP_MD5
 #include <openssl/evp.h>
 #else
+#ifdef ENABLE_OPENSSL_MD5
 #include <openssl/md5.h>
+#else
+#ifdef ENABLE_LIBMD_MD5
+#include <md5.h>
+#endif
+#endif
 #endif
 #endif
 
@@ -44,7 +49,7 @@
 int librfc3041_calc(ipv6calc_ipv6addr *identifier, ipv6calc_ipv6addr *token, ipv6calc_ipv6addr *newidentifier, ipv6calc_ipv6addr *newtoken) {
 	int retval = 1;
 	unsigned int i;
-	char tempstring[IPV6CALC_STRING_MAX],  tempstring2[IPV6CALC_STRING_MAX];
+	char tempstring[IPV6CALC_STRING_MAX] = "", tempstring2[IPV6CALC_STRING_MAX];
 
 	DEBUGPRINT_WA(DEBUG_librfc3041, "Got identifier '%08x-%08x' and token '%08x-%08x'", (unsigned int) ipv6addr_getdword(identifier, 2), (unsigned int) ipv6addr_getdword(identifier, 3), (unsigned int) ipv6addr_getdword(token, 2), (unsigned int) ipv6addr_getdword(token, 3));
 
@@ -92,6 +97,16 @@ int librfc3041_calc(ipv6calc_ipv6addr *identifier, ipv6calc_ipv6addr *token, ipv
 	MD5_Update(&md5hash, &token->in6_addr.s6_addr[8], 8);
 	MD5_Final(digest, &md5hash);
 #else // ENABLE_OPENSSL_MD5
+#ifdef ENABLE_LIBMD_MD5
+	unsigned int digest_len = MD5_DIGEST_LENGTH;
+	unsigned char digest[MD5_DIGEST_LENGTH];
+	MD5_CTX md5hash;
+
+	MD5Init(&md5hash);
+	MD5Update(&md5hash, &identifier->in6_addr.s6_addr[8], 8);
+	MD5Update(&md5hash, &token->in6_addr.s6_addr[8], 8);
+	MD5Final(digest, &md5hash);
+#else // ENABLE_LIBMD_MD5
 	// fallback to bundled MD5
 	unsigned int digest_len = MD5_DIGEST_LENGTH;
 	unsigned char digest[MD5_DIGEST_LENGTH];
@@ -101,15 +116,16 @@ int librfc3041_calc(ipv6calc_ipv6addr *identifier, ipv6calc_ipv6addr *token, ipv
 	md5_process_bytes(&identifier->in6_addr.s6_addr[8], 8, &md5hash);
 	md5_process_bytes(&token->in6_addr.s6_addr[8], 8, &md5hash);
 	md5_finish_ctx(&md5hash, digest);
+#endif // ENABLE_LIBMD_MD5
 #endif // ENABLE_OPENSSL_MD5
 
 #endif // ENABLE_OPENSSL_EVP_MD5
 
-	tempstring[0] = '\0';
+	STRCLR(tempstring);
 
 	for (i = 0; i < digest_len; i++) {
-		snprintf(tempstring2, sizeof(tempstring2), "%s%02x", tempstring, (int) digest[i]);
-		snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+		snprintf(tempstring2, sizeof(tempstring2), "%02x", (int) digest[i]);
+		STRCAT(tempstring, tempstring2);
 	};
 	
 	DEBUGPRINT_WA(DEBUG_librfc3041, "MD5 hash '%s'", tempstring);
