@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc/mod_ipv6calc
  * File       : mod_ipv6calc.c
- * Version    : $Id: 674ebcc6ca8c28e57028086a149c591329175681 $
- * Copyright  : 2015-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2015-2024 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc Apache module
@@ -116,10 +115,11 @@ int    longopts_maxentries = 0;
 static const char *set_ipv6calc_enable(cmd_parms *cmd, void *dummy, int arg);
 static const char *set_ipv6calc_default_active(cmd_parms *cmd, void *dummy, int arg);
 static const char *set_ipv6calc_no_fallback(cmd_parms *cmd, void *dummy, int arg);
+static const char *set_ipv6calc_source_env_name(cmd_parms *cmd, void *dummy, const char *value);
 static const char *set_ipv6calc_cache(cmd_parms *cmd, void *dummy, int arg);
-static const char *set_ipv6calc_cache_limit(cmd_parms *cmd, void *dummy, const char *value, int arg);
-static const char *set_ipv6calc_cache_statistics_interval(cmd_parms *cmd, void *dummy, const char *value, int arg);
-static const char *set_ipv6calc_debuglevel(cmd_parms *cmd, void *dummy, const char *value, int arg);
+static const char *set_ipv6calc_cache_limit(cmd_parms *cmd, void *dummy, const char *value);
+static const char *set_ipv6calc_cache_statistics_interval(cmd_parms *cmd, void *dummy, const char *value);
+static const char *set_ipv6calc_debuglevel(cmd_parms *cmd, void *dummy, const char *value);
 
 static const char *set_ipv6calc_action_anonymize(cmd_parms *cmd, void *dummy, int arg);
 static const char *set_ipv6calc_action_countrycode(cmd_parms *cmd, void *dummy, int arg);
@@ -127,7 +127,7 @@ static const char *set_ipv6calc_action_asn(cmd_parms *cmd, void *dummy, int arg)
 static const char *set_ipv6calc_action_registry(cmd_parms *cmd, void *dummy, int arg);
 static const char *set_ipv6calc_action_geonameid(cmd_parms *cmd, void *dummy, int arg);
 
-static const char *set_ipv6calc_option(cmd_parms *cmd, void *dummy, const char *name, const char *value, int arg);
+static const char *set_ipv6calc_option(cmd_parms *cmd, void *dummy, const char *name, const char *value);
 
 
 /***************************
@@ -176,6 +176,8 @@ typedef struct {
 
 	int no_fallback;
 
+	char source_env_name[MAX_STRING_LEN];
+
 	int cache;
 	int cache_limit;
 	unsigned long int cache_statistics_interval;
@@ -210,20 +212,22 @@ int ipv6calc_option_list_entries = 0;
 /*
  * Config options (ipv6calc_cmds)
  */
+#pragma GCC diagnostic ignored "-Wmissing-field-initializers" // command_rec -> {NULL}
 static const command_rec ipv6calc_cmds[] = {
 	AP_INIT_FLAG("ipv6calcEnable", set_ipv6calc_enable, NULL, OR_FILEINFO, "Turn on mod_ipv6calc"),
 	AP_INIT_FLAG("ipv6calcDefaultActive", set_ipv6calc_default_active, NULL, OR_FILEINFO, "mod_ipv6calc active by default (on/off can be controlled by environment)"),
 	AP_INIT_FLAG("ipv6calcNoFallback", set_ipv6calc_no_fallback, NULL, OR_FILEINFO, "Do not fallback in case of issues with mod_ipv6calc"),
+	AP_INIT_TAKE1("ipv6calcSourceEnvName", set_ipv6calc_source_env_name, NULL, OR_FILEINFO, "mod_ipv6calc source of IP address environment name: <NAME_ENV>"),
 	AP_INIT_FLAG("ipv6calcCache", set_ipv6calc_cache, NULL, OR_FILEINFO, "Turn off mod_ipv6calc cache"),
-	AP_INIT_TAKE1("ipv6calcCacheLimit",  (const char *(*)()) set_ipv6calc_cache_limit, NULL, OR_FILEINFO, "mod_ipv6calc cache limit: <value>"),
-	AP_INIT_TAKE1("ipv6calcCacheStatisticsInterval",  (const char *(*)()) set_ipv6calc_cache_statistics_interval, NULL, OR_FILEINFO, "mod_ipv6calc cache statistics interval: <value> (0=disabled)"),
-	AP_INIT_TAKE1("ipv6calcDebuglevel",  (const char *(*)()) set_ipv6calc_debuglevel, NULL, OR_FILEINFO, "Debug level of module (binary or'ed): <value>"),
+	AP_INIT_TAKE1("ipv6calcCacheLimit", set_ipv6calc_cache_limit, NULL, OR_FILEINFO, "mod_ipv6calc cache limit: <value>"),
+	AP_INIT_TAKE1("ipv6calcCacheStatisticsInterval", set_ipv6calc_cache_statistics_interval, NULL, OR_FILEINFO, "mod_ipv6calc cache statistics interval: <value> (0=disabled)"),
+	AP_INIT_TAKE1("ipv6calcDebuglevel", set_ipv6calc_debuglevel, NULL, OR_FILEINFO, "Debug level of module (binary or'ed): <value>"),
 	AP_INIT_FLAG("ipv6calcActionAnonymize", set_ipv6calc_action_anonymize, NULL, OR_FILEINFO, "Store anonymized IP address in IPV6CALC_CLIENT_IP_ANON"),
 	AP_INIT_FLAG("ipv6calcActionCountrycode", set_ipv6calc_action_countrycode, NULL, OR_FILEINFO, "Store Country Code of IP address in IPV6CALC_CLIENT_COUNTRYCODE"),
 	AP_INIT_FLAG("ipv6calcActionAsn", set_ipv6calc_action_asn, NULL, OR_FILEINFO, "Store ASN of IP address in IPV6CALC_CLIENT_ASN"),
 	AP_INIT_FLAG("ipv6calcActionRegistry", set_ipv6calc_action_registry, NULL, OR_FILEINFO, "Store Registry of IP address in IPV6CALC_CLIENT_REGISTRY"),
 	AP_INIT_FLAG("ipv6calcActionGeonameid", set_ipv6calc_action_geonameid, NULL, OR_FILEINFO, "Store GeonameID of IP address in IPV6CALC_CLIENT_GEONAMEID"),
-	AP_INIT_TAKE2("ipv6calcOption",  (const char *(*)()) set_ipv6calc_option, NULL, OR_FILEINFO, "Define ipv6calc option: <key> <value>"),
+	AP_INIT_TAKE2("ipv6calcOption", set_ipv6calc_option, NULL, OR_FILEINFO, "Define ipv6calc option: <key> <value>"),
 	{NULL} 
 };
 
@@ -345,19 +349,15 @@ static int ipv6calc_support_init(server_rec *s) {
  * Hooks functions
  ***************************/
 
-/*
- * ipv6calc_cleanup
- */
-static apr_status_t ipv6calc_cleanup(void *cfgdata) {
-	// cleanup ipv6calc database wrapper
-	libipv6calc_cleanup();
-	return APR_SUCCESS;
-};
 
 /*
  * ipv6calc_post_config
  */
 static int ipv6calc_post_config(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t *ptemp, server_rec *s) {
+	UNUSED(pconf);
+	UNUSED(plog);
+	UNUSED(ptemp);
+
 	char string[IPV6CALC_STRING_MAX] = "";
 	int result;
 
@@ -384,6 +384,18 @@ static int ipv6calc_post_config(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t
 		);
 	};
 
+	// check source of client address
+	if (strlen(config->source_env_name) > 0) {
+		ap_log_error(APLOG_MARK, APLOG_NOTICE, 0, s
+			, "client address is taken from enviroment: %s"
+			, config->source_env_name
+		);
+	} else {
+		ap_log_error(APLOG_MARK, APLOG_NOTICE, 0, s
+			, "client address is taken from socket"
+		);
+	};
+
 #ifdef SHARED_LIBRARY
 	IPV6CALC_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
 	IPV6CALC_DB_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
@@ -466,7 +478,7 @@ static int ipv6calc_post_config(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t
 		, string
 	);
 
-	if (config->debuglevel && IPV6CALC_DEBUG_SHOW_DB_INFO) {
+	if (config->debuglevel & IPV6CALC_DEBUG_SHOW_DB_INFO) {
 		libipv6calc_db_wrapper_print_db_info(0, "");
 	};
 
@@ -534,8 +546,7 @@ static int ipv6calc_post_config(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t
  * ipv6calc_child_init
  */
 static void ipv6calc_child_init(apr_pool_t *p, server_rec *s) {
-
-	apr_pool_cleanup_register(p, NULL, ipv6calc_cleanup, ipv6calc_cleanup);
+	UNUSED(p);
 
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(s->module_config, &ipv6calc_module);
 
@@ -553,34 +564,6 @@ static void ipv6calc_child_init(apr_pool_t *p, server_rec *s) {
 		, "ipv6calc_child_init"
 	);
 
-	ipv6calc_support_init(s);
-
-	/* check for KeepTypeAsnCC support */
-	if ((libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV4_REQ_DB) == 1) \
-	    && (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV6_REQ_DB) == 1)) {
-		feature_kp = 1;
-	};
-
-	/* check for KeepTypeAsnCC support */
-	if ((libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEGEONAMEID_IPV4_REQ_DB) == 1) \
-	    && (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEGEONAMEID_IPV6_REQ_DB) == 1)) {
-		feature_kg = 1;
-	};
-
-	if (config->ipv6calc_anon_set.method == ANON_METHOD_KEEPTYPEASNCC) {
-		if (feature_kp == 0) {
-			// fallback
-			libipv6calc_anon_set_by_name(&config->ipv6calc_anon_set, "as"); // anonymize standard
-		};
-	};
-
-	if (config->ipv6calc_anon_set.method == ANON_METHOD_KEEPTYPEGEONAMEID) {
-		if (feature_kg == 0) {
-			// fallback
-			libipv6calc_anon_set_by_name(&config->ipv6calc_anon_set, "as"); // anonymize standard
-		};
-	};
-
 	return;
 };
 
@@ -597,6 +580,9 @@ static int ipv6calc_post_read_request(request_rec *r) {
 
 	// Apache/APR related includes
 	apr_sockaddr_t *client_addr_p; // structure defined in apr_network_io.h
+	apr_sockaddr_t *client_addr_p_source_env; // structure defined in apr_network_io.h
+	apr_status_t status;
+
 	ipv6calc_server_config* config;
 
 	// ipv6calc related
@@ -612,6 +598,8 @@ static int ipv6calc_post_read_request(request_rec *r) {
 	char asn[APRMAXHOSTLEN];
 	char registry[APRMAXHOSTLEN];
 	char geonameid[APRMAXHOSTLEN];
+	const char *source_env_content;
+	const char *client_ip;
 	unsigned int data_source;
 
 	int result;
@@ -645,6 +633,7 @@ static int ipv6calc_post_read_request(request_rec *r) {
 		if (! apr_table_get(r->subprocess_env, ENV_ipv6calcActive)) {
 			ap_log_rerror(APLOG_MARK, mod_ipv6calc_APLOG_DEBUG, 0, r, "configuration 'ipv6calcDefaultActive off', NOT found in environment '%s' (return '-PbD-')", ENV_ipv6calcActive);
 			// pdb <-> Passive by Default
+			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_IP", "-PbD-");
 			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_COUNTRYCODE", "-PbD-");
 			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_ASN", "-PbD-");
 			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_REGISTRY", "-PbD-");
@@ -660,6 +649,7 @@ static int ipv6calc_post_read_request(request_rec *r) {
 		if (apr_table_get(r->subprocess_env, ENV_ipv6calcPassive)) {
 			ap_log_rerror(APLOG_MARK, mod_ipv6calc_APLOG_DEBUG, 0, r, "configuration 'ipv6calcDefaultActive on', found in environment '%s' (return '-PbE')", ENV_ipv6calcPassive);
 			// pdb <-> Passive by Environment
+			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_IP", "-PbE-");
 			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_COUNTRYCODE", "-PbE-");
 			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_ASN", "-PbE-");
 			apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_REGISTRY", "-PbE-");
@@ -672,23 +662,40 @@ static int ipv6calc_post_read_request(request_rec *r) {
 		};
 	};
 
-	// get client address (aka REMOTE_IP)
+	// get client address (aka REMOTE_ADDR)
 #if (((AP_SERVER_MAJORVERSION_NUMBER == 2) && (AP_SERVER_MINORVERSION_NUMBER >= 4)) || (AP_SERVER_MAJORVERSION_NUMBER > 2))
 	client_addr_p = r->connection->client_addr;
+	client_ip = r->connection->client_ip;
 #else
 	client_addr_p = r->connection->remote_addr;
+	client_ip = r->connection->remote_ip;
 #endif
 
+	if (strlen(config->source_env_name) > 0) {
+		source_env_content = apr_table_get(r->subprocess_env, config->source_env_name);
+		if (source_env_content != NULL) {
+			ap_log_rerror(APLOG_MARK, mod_ipv6calc_APLOG_DEBUG, 0, r, "found in environment for client address source: %s=%s", config->source_env_name, source_env_content);
+			status = apr_sockaddr_info_get(&client_addr_p_source_env, source_env_content, APR_UNSPEC, 0, 0, r->pool);
+			if (status == APR_SUCCESS) {
+				ap_log_rerror(APLOG_MARK, mod_ipv6calc_APLOG_DEBUG, 0, r, "client address found in environment parsed OK: %s=%s", config->source_env_name, source_env_content);
+				client_addr_p = client_addr_p_source_env;
+				client_ip = source_env_content;
+			} else {
+				ap_log_rerror(APLOG_MARK, APLOG_WARNING, 0, r, "cannot parse client address found in environment: %s=%s", config->source_env_name, source_env_content);
+			};
+		} else {
+			ap_log_rerror(APLOG_MARK, mod_ipv6calc_APLOG_DEBUG, 0, r, "NOT found in environment for client address source: %s", config->source_env_name);
+		};
+	};
+
 	ap_log_rerror(APLOG_MARK, (config->debuglevel & IPV6CALC_DEBUG_SHOW_CLIENT_IP) ? APLOG_NOTICE : mod_ipv6calc_APLOG_DEBUG, 0, r
 		, "client IP address: %s  family: %d"
-#if (((AP_SERVER_MAJORVERSION_NUMBER == 2) && (AP_SERVER_MINORVERSION_NUMBER >= 4)) || (AP_SERVER_MAJORVERSION_NUMBER > 2))
-		, r->connection->client_ip
-#else
-		, r->connection->remote_ip
-#endif
+		, client_ip
 		, client_addr_p->family
 	);
 
+	apr_table_set(r->subprocess_env, "IPV6CALC_CLIENT_IP", client_ip);
+
 	// convert address into ipv6calc structure
 	libipaddr_clearall(&ipaddr);
 
@@ -751,15 +758,15 @@ static int ipv6calc_post_read_request(request_rec *r) {
 				if (pi == mod_ipv6calc_pi_IPV4) {
 					ap_log_rerror(APLOG_MARK, APLOG_NOTICE, 0, r
 						, "IPv4 address to lookup in cache: %08x"
-						, (p_mapped == 0) ? client_addr_p->sa.sin.sin_addr.s_addr : client_addr_p->sa.sin6.sin6_addr.s6_addr32[3]
+						, (p_mapped == 0) ? ntohl(client_addr_p->sa.sin.sin_addr.s_addr) : ntohl(client_addr_p->sa.sin6.sin6_addr.s6_addr32[3])
 					);
 				} else if (pi == mod_ipv6calc_pi_IPV6) {
 					ap_log_rerror(APLOG_MARK, APLOG_NOTICE, 0, r
 						, "IPv6 address to lookup in cache: %08x %08x %08x %08x"
-						, client_addr_p->sa.sin6.sin6_addr.s6_addr32[0]
-						, client_addr_p->sa.sin6.sin6_addr.s6_addr32[1]
-						, client_addr_p->sa.sin6.sin6_addr.s6_addr32[2]
-						, client_addr_p->sa.sin6.sin6_addr.s6_addr32[3]
+						, ntohl(client_addr_p->sa.sin6.sin6_addr.s6_addr32[0])
+						, ntohl(client_addr_p->sa.sin6.sin6_addr.s6_addr32[1])
+						, ntohl(client_addr_p->sa.sin6.sin6_addr.s6_addr32[2])
+						, ntohl(client_addr_p->sa.sin6.sin6_addr.s6_addr32[3])
 					);
 				};
 			};
@@ -770,16 +777,16 @@ static int ipv6calc_post_read_request(request_rec *r) {
 						ap_log_rerror(APLOG_MARK, APLOG_NOTICE, 0, r
 							, "IPv4 address in cache       %3d: %08x"
 							, i
-							, ipv6calc_cache_lri_ipv4_token[i].s_addr
+							, ntohl(ipv6calc_cache_lri_ipv4_token[i].s_addr)
 						);
 					} else if (pi == mod_ipv6calc_pi_IPV6) {
 						ap_log_rerror(APLOG_MARK, APLOG_NOTICE, 0, r
 							, "IPv6 address in cache       %3d: %08x %08x %08x %08x"
 							, i
-							, ipv6calc_cache_lri_ipv6_token[i].s6_addr32[0]
-							, ipv6calc_cache_lri_ipv6_token[i].s6_addr32[1]
-							, ipv6calc_cache_lri_ipv6_token[i].s6_addr32[2]
-							, ipv6calc_cache_lri_ipv6_token[i].s6_addr32[3]
+							, ntohl(ipv6calc_cache_lri_ipv6_token[i].s6_addr32[0])
+							, ntohl(ipv6calc_cache_lri_ipv6_token[i].s6_addr32[1])
+							, ntohl(ipv6calc_cache_lri_ipv6_token[i].s6_addr32[2])
+							, ntohl(ipv6calc_cache_lri_ipv6_token[i].s6_addr32[3])
 						);
 					};
 				};
@@ -1085,7 +1092,7 @@ static int ipv6calc_post_read_request(request_rec *r) {
 		// set ASN of IP in environment
 		if (config->action_asn == 1) {
 			if (retrieve_asn != 0) {
-				asn_num = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, NULL);
+				asn_num = libipv6calc_db_wrapper_as_num32_by_addr(&ipaddr, NULL, NULL, 0);
 
 				snprintf(asn, sizeof(asn), "%u", asn_num);
 
@@ -1275,6 +1282,8 @@ static int ipv6calc_post_read_request(request_rec *r) {
  * set_ipv6calc_enable
  */
 static const char *set_ipv6calc_enable(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 	
 	if (!config) {
@@ -1291,6 +1300,8 @@ static const char *set_ipv6calc_enable(cmd_parms *cmd, void *dummy, int arg) {
  * set_ipv6calc_default_active
  */
 static const char *set_ipv6calc_default_active(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1307,6 +1318,8 @@ static const char *set_ipv6calc_default_active(cmd_parms *cmd, void *dummy, int
  * set_ipv6calc_no_fallback
  */
 static const char *set_ipv6calc_no_fallback(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 	
 	if (!config) {
@@ -1318,11 +1331,41 @@ static const char *set_ipv6calc_no_fallback(cmd_parms *cmd, void *dummy, int arg
 	return NULL;
 };
 
+/*
+ * set_ipv6calc_source_env_name
+ */
+static const char *set_ipv6calc_source_env_name(cmd_parms *cmd, void *dummy, const char *value) {
+	UNUSED(dummy);
+
+	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
+
+	if (!config) {
+		return NULL;
+	};
+
+	if (strlen(value) >= sizeof(config->source_env_name)) {
+		ap_log_error(APLOG_MARK, APLOG_WARNING, 0, cmd->server
+#ifdef __i386__
+			, "config option ipv6calcSourceEnvName: string too long (skip): %u >= %u"
+#else
+			, "config option ipv6calcSourceEnvName: string too long (skip): %lu >= %lu"
+#endif
+			, strlen(value)
+			, sizeof(config->source_env_name)
+		);
+	} else {
+		strncpy(config->source_env_name, value, sizeof(config->source_env_name) - 1);
+	};
+
+	return NULL;
+};
 
 /*
  * set_ipv6calc_cache
  */
 static const char *set_ipv6calc_cache(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 	
 	if (!config) {
@@ -1338,7 +1381,9 @@ static const char *set_ipv6calc_cache(cmd_parms *cmd, void *dummy, int arg) {
 /*
  * set_ipv6calc_cache_limit
  */
-static const char *set_ipv6calc_cache_limit(cmd_parms *cmd, void *dummy, const char *value, int arg) {
+static const char *set_ipv6calc_cache_limit(cmd_parms *cmd, void *dummy, const char *value) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1379,7 +1424,9 @@ static const char *set_ipv6calc_cache_limit(cmd_parms *cmd, void *dummy, const c
 /*
  * set_ipv6calc_cache_statistics_interval
  */
-static const char *set_ipv6calc_cache_statistics_interval(cmd_parms *cmd, void *dummy, const char *value, int arg) {
+static const char *set_ipv6calc_cache_statistics_interval(cmd_parms *cmd, void *dummy, const char *value) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1409,7 +1456,9 @@ static const char *set_ipv6calc_cache_statistics_interval(cmd_parms *cmd, void *
 /*
  * set_ipv6calc_debuglevel
  */
-static const char *set_ipv6calc_debuglevel(cmd_parms *cmd, void *dummy, const char *value, int arg) {
+static const char *set_ipv6calc_debuglevel(cmd_parms *cmd, void *dummy, const char *value) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1444,6 +1493,8 @@ static const char *set_ipv6calc_debuglevel(cmd_parms *cmd, void *dummy, const ch
  * set_ipv6calc_countrycode
  */
 static const char *set_ipv6calc_action_countrycode(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1460,6 +1511,8 @@ static const char *set_ipv6calc_action_countrycode(cmd_parms *cmd, void *dummy,
  * set_ipv6calc_asn
  */
 static const char *set_ipv6calc_action_asn(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1476,6 +1529,8 @@ static const char *set_ipv6calc_action_asn(cmd_parms *cmd, void *dummy, int arg)
  * set_ipv6calc_registry
  */
 static const char *set_ipv6calc_action_registry(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1492,6 +1547,8 @@ static const char *set_ipv6calc_action_registry(cmd_parms *cmd, void *dummy, int
  * set_ipv6calc_geonameid
  */
 static const char *set_ipv6calc_action_geonameid(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1508,6 +1565,8 @@ static const char *set_ipv6calc_action_geonameid(cmd_parms *cmd, void *dummy, in
  * set_ipv6calc_anonymize
  */
 static const char *set_ipv6calc_action_anonymize(cmd_parms *cmd, void *dummy, int arg) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 	
 	if (!config) {
@@ -1522,9 +1581,10 @@ static const char *set_ipv6calc_action_anonymize(cmd_parms *cmd, void *dummy, in
 
 /*
  * set_ipv6calc_option
- *  set generic ipv6calc option
  */
-static const char *set_ipv6calc_option(cmd_parms *cmd, void *dummy, const char *name, const char *value, int arg) {
+static const char *set_ipv6calc_option(cmd_parms *cmd, void *dummy, const char *name, const char *value) {
+	UNUSED(dummy);
+
 	ipv6calc_server_config *config = (ipv6calc_server_config*) ap_get_module_config(cmd->server->module_config, &ipv6calc_module);
 
 	if (!config) {
@@ -1553,6 +1613,8 @@ static const char *set_ipv6calc_option(cmd_parms *cmd, void *dummy, const char *
  * ipv6calc_create_svr_conf
  */
 static void *ipv6calc_create_svr_conf(apr_pool_t* pool, server_rec* svr) {
+	UNUSED(svr);
+
 	ipv6calc_server_config* svr_cfg = apr_pcalloc(pool, sizeof(ipv6calc_server_config));
 	
 	svr_cfg->enabled = 0;
@@ -1561,6 +1623,9 @@ static void *ipv6calc_create_svr_conf(apr_pool_t* pool, server_rec* svr) {
 
 	svr_cfg->no_fallback = 0;
 
+	// source toggle
+	svr_cfg->source_env_name[0] = '\0';
+
 	// cache settings
 	svr_cfg->cache = 1; // default: on
 	svr_cfg->cache_limit = IPV6CALC_CACHE_LRI_LIMIT_MIN; /* optimum ?? */
@@ -1585,6 +1650,8 @@ static void *ipv6calc_create_svr_conf(apr_pool_t* pool, server_rec* svr) {
  * ipv6calc_register_hooks
  */
 static void ipv6calc_register_hooks(apr_pool_t *p) {
+	UNUSED(p);
+
 	ap_hook_post_config(ipv6calc_post_config, NULL, NULL, APR_HOOK_MIDDLE);
 	ap_hook_child_init(ipv6calc_child_init, NULL, NULL, APR_HOOK_MIDDLE);
 	ap_hook_fixups(ipv6calc_post_read_request, NULL, NULL, APR_HOOK_MIDDLE);
@@ -1594,7 +1661,10 @@ static void ipv6calc_register_hooks(apr_pool_t *p) {
 /*
  * mod_ipv6calc API hooks
  */
-#if (((AP_SERVER_MAJORVERSION_NUMBER == 2) && (AP_SERVER_MINORVERSION_NUMBER >= 4)) || (AP_SERVER_MAJORVERSION_NUMBER > 2))
+#if ( \
+	((AP_SERVER_MAJORVERSION_NUMBER == 2) && (AP_SERVER_MINORVERSION_NUMBER >= 4)) \
+     || (AP_SERVER_MAJORVERSION_NUMBER > 2) \
+)
 AP_DECLARE_MODULE(ipv6calc) = {
 #else
 module AP_MODULE_DECLARE_DATA ipv6calc_module = {
@@ -1605,7 +1675,14 @@ module AP_MODULE_DECLARE_DATA ipv6calc_module = {
 	ipv6calc_create_svr_conf,    /* create per-server config structures */
 	NULL,                        /* merge  per-server config structures */
 	ipv6calc_cmds,               /* table of config file commands       */
-	ipv6calc_register_hooks      /* register hooks                      */
+	ipv6calc_register_hooks,     /* register hooks                      */
+#if ( \
+	((AP_SERVER_MAJORVERSION_NUMBER == 2) && (AP_SERVER_MINORVERSION_NUMBER == 4) && (AP_SERVER_PATCHLEVEL_NUMBER >= 37)) \
+    ||	((AP_SERVER_MAJORVERSION_NUMBER == 2) && (AP_SERVER_MINORVERSION_NUMBER > 4)) \
+    ||  (AP_SERVER_MAJORVERSION_NUMBER > 2) \
+)
+	0,                           /* flags                               */ // not found in 2.4.6, found in 2.4.37
+#endif
 };
 
 
